# coding: utf-8

# flake8: noqa

"""
    projects-api

    These APIs allows you to create workflow statuses, which are then assigned to workflows. These workflows, containing multiple statuses, are subsequently linked to projects. Additionally, candidates are associated with projects, defining the path they are meant to follow within the established workflows.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

from __future__ import absolute_import

# import apis into sdk package
from phenom.api.projects.candidates_api import CandidatesApi
from phenom.api.projects.projects_api import ProjectsApi
from phenom.api.projects.workflow_status_api import WorkflowStatusApi
from phenom.api.projects.workflows_api import WorkflowsApi
# import ApiClient
from phenom.commons.api_client import ApiClient
from phenom.commons.configuration import Configuration
# import models into sdk package
from phenom.api.projects.models.assign_candidate_to_project_response import AssignCandidateToProjectResponse
from phenom.api.projects.models.assign_candidates_to_project import AssignCandidatesToProject
from phenom.api.projects.models.assign_candidates_to_project_candidate_infos import AssignCandidatesToProjectCandidateInfos
from phenom.api.projects.models.bad_request import BadRequest
from phenom.api.projects.models.bad_request_error import BadRequestError
from phenom.api.projects.models.bad_request_error_errors import BadRequestErrorErrors
from phenom.api.projects.models.bad_request_errors import BadRequestErrors
from phenom.api.projects.models.create_project_request import CreateProjectRequest
from phenom.api.projects.models.create_project_request_category_list import CreateProjectRequestCategoryList
from phenom.api.projects.models.create_project_request_created_recruiter_info import CreateProjectRequestCreatedRecruiterInfo
from phenom.api.projects.models.create_project_request_hiring_team_list import CreateProjectRequestHiringTeamList
from phenom.api.projects.models.create_project_request_project_attachment_list import CreateProjectRequestProjectAttachmentList
from phenom.api.projects.models.create_workflow_request import CreateWorkflowRequest
from phenom.api.projects.models.create_workflow_request_further_transition_stages import CreateWorkflowRequestFurtherTransitionStages
from phenom.api.projects.models.create_workflow_request_stages import CreateWorkflowRequestStages
from phenom.api.projects.models.create_workflow_status_request import CreateWorkflowStatusRequest
from phenom.api.projects.models.create_workflow_status_request_created_by_recruiter_info import CreateWorkflowStatusRequestCreatedByRecruiterInfo
from phenom.api.projects.models.creation_response import CreationResponse
from phenom.api.projects.models.delete_candidate_from_project import DeleteCandidateFromProject
from phenom.api.projects.models.delete_workflow_response import DeleteWorkflowResponse
from phenom.api.projects.models.delete_workflow_status_response import DeleteWorkflowStatusResponse
from phenom.api.projects.models.get_all_projects_response import GetAllProjectsResponse
from phenom.api.projects.models.get_all_projects_response_created_recruiter_info import GetAllProjectsResponseCreatedRecruiterInfo
from phenom.api.projects.models.get_all_projects_response_data import GetAllProjectsResponseData
from phenom.api.projects.models.get_all_projects_response_pagination import GetAllProjectsResponsePagination
from phenom.api.projects.models.get_all_workflow_response import GetAllWorkflowResponse
from phenom.api.projects.models.get_all_workflow_response_created_by_recruiter_info import GetAllWorkflowResponseCreatedByRecruiterInfo
from phenom.api.projects.models.get_all_workflow_response_data import GetAllWorkflowResponseData
from phenom.api.projects.models.get_all_workflow_response_further_transition_stages import GetAllWorkflowResponseFurtherTransitionStages
from phenom.api.projects.models.get_all_workflow_response_stages import GetAllWorkflowResponseStages
from phenom.api.projects.models.get_all_workflow_status_response import GetAllWorkflowStatusResponse
from phenom.api.projects.models.get_all_workflow_status_response_created_by_recruiter_info import GetAllWorkflowStatusResponseCreatedByRecruiterInfo
from phenom.api.projects.models.get_all_workflow_status_response_data import GetAllWorkflowStatusResponseData
from phenom.api.projects.models.get_all_workflow_status_response_pagination import GetAllWorkflowStatusResponsePagination
from phenom.api.projects.models.get_project_activities_response import GetProjectActivitiesResponse
from phenom.api.projects.models.get_project_activities_response_data import GetProjectActivitiesResponseData
from phenom.api.projects.models.get_project_activities_response_pagination import GetProjectActivitiesResponsePagination
from phenom.api.projects.models.get_project_activities_response_scope_attr import GetProjectActivitiesResponseScopeAttr
from phenom.api.projects.models.get_project_associations_response import GetProjectAssociationsResponse
from phenom.api.projects.models.get_project_associations_response_pagination import GetProjectAssociationsResponsePagination
from phenom.api.projects.models.get_projects_response import GetProjectsResponse
from phenom.api.projects.models.get_projects_response_candidate_infos import GetProjectsResponseCandidateInfos
from phenom.api.projects.models.get_projects_response_created_recruiter_info import GetProjectsResponseCreatedRecruiterInfo
from phenom.api.projects.models.get_projects_response_data import GetProjectsResponseData
from phenom.api.projects.models.get_projects_response_hiring_team_list import GetProjectsResponseHiringTeamList
from phenom.api.projects.models.get_projects_response_matching_criteria import GetProjectsResponseMatchingCriteria
from phenom.api.projects.models.get_projects_response_matching_criteria_distance import GetProjectsResponseMatchingCriteriaDistance
from phenom.api.projects.models.get_projects_response_matching_criteria_years_of_experience import GetProjectsResponseMatchingCriteriaYearsOfExperience
from phenom.api.projects.models.get_projects_response_updated_recruiter_info import GetProjectsResponseUpdatedRecruiterInfo
from phenom.api.projects.models.get_workflow_response import GetWorkflowResponse
from phenom.api.projects.models.get_workflow_response_associated_projects import GetWorkflowResponseAssociatedProjects
from phenom.api.projects.models.get_workflow_response_created_by_recruiter_info import GetWorkflowResponseCreatedByRecruiterInfo
from phenom.api.projects.models.get_workflow_response_data import GetWorkflowResponseData
from phenom.api.projects.models.get_workflow_response_further_transition_stages import GetWorkflowResponseFurtherTransitionStages
from phenom.api.projects.models.get_workflow_response_stages import GetWorkflowResponseStages
from phenom.api.projects.models.get_workflow_response_updated_by_recruiter_info import GetWorkflowResponseUpdatedByRecruiterInfo
from phenom.api.projects.models.get_workflow_status_response import GetWorkflowStatusResponse
from phenom.api.projects.models.get_workflow_status_response_associated_workflows import GetWorkflowStatusResponseAssociatedWorkflows
from phenom.api.projects.models.get_workflow_status_response_created_by_recruiter_info import GetWorkflowStatusResponseCreatedByRecruiterInfo
from phenom.api.projects.models.get_workflow_status_response_data import GetWorkflowStatusResponseData
from phenom.api.projects.models.internal_server_error import InternalServerError
from phenom.api.projects.models.no_content_response import NoContentResponse
from phenom.api.projects.models.not_found_error import NotFoundError
from phenom.api.projects.models.replace_workflow_request import ReplaceWorkflowRequest
from phenom.api.projects.models.replace_workflow_request_further_transition_stages import ReplaceWorkflowRequestFurtherTransitionStages
from phenom.api.projects.models.replace_workflow_request_stages import ReplaceWorkflowRequestStages
from phenom.api.projects.models.update_project_request import UpdateProjectRequest
from phenom.api.projects.models.update_project_request_candidate_infos import UpdateProjectRequestCandidateInfos
from phenom.api.projects.models.update_project_request_category_list import UpdateProjectRequestCategoryList
from phenom.api.projects.models.update_project_request_updated_recruiter_info import UpdateProjectRequestUpdatedRecruiterInfo
from phenom.api.projects.models.update_project_response import UpdateProjectResponse
from phenom.api.projects.models.update_workflow_request import UpdateWorkflowRequest
from phenom.api.projects.models.update_workflow_request_stages import UpdateWorkflowRequestStages
from phenom.api.projects.models.update_workflow_response import UpdateWorkflowResponse



# coding: utf-8

"""
    videoplatform-api

    Interview Screening APIs allows to invite candidate to interview, evaluate and review candidates interview performances.  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@phenompeople.com
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class GetQuestionnaireDetailsResponseDataQuestionTranslations(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'language': 'str',
        'locale': 'str',
        'question_text': 'str'
    }

    attribute_map = {
        'language': 'language',
        'locale': 'locale',
        'question_text': 'questionText'
    }

    def __init__(self, language=None, locale=None, question_text=None):  # noqa: E501
        """GetQuestionnaireDetailsResponseDataQuestionTranslations - a model defined in Swagger"""  # noqa: E501
        self._language = None
        self._locale = None
        self._question_text = None
        self.discriminator = None
        self.language = language
        self.locale = locale
        self.question_text = question_text

    @property
    def language(self):
        """Gets the language of this GetQuestionnaireDetailsResponseDataQuestionTranslations.  # noqa: E501

        Language for which question is translated.  # noqa: E501

        :return: The language of this GetQuestionnaireDetailsResponseDataQuestionTranslations.  # noqa: E501
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this GetQuestionnaireDetailsResponseDataQuestionTranslations.

        Language for which question is translated.  # noqa: E501

        :param language: The language of this GetQuestionnaireDetailsResponseDataQuestionTranslations.  # noqa: E501
        :type: str
        """
        if language is None:
            raise ValueError("Invalid value for `language`, must not be `None`")  # noqa: E501

        self._language = language

    @property
    def locale(self):
        """Gets the locale of this GetQuestionnaireDetailsResponseDataQuestionTranslations.  # noqa: E501

        Locale for the language.  # noqa: E501

        :return: The locale of this GetQuestionnaireDetailsResponseDataQuestionTranslations.  # noqa: E501
        :rtype: str
        """
        return self._locale

    @locale.setter
    def locale(self, locale):
        """Sets the locale of this GetQuestionnaireDetailsResponseDataQuestionTranslations.

        Locale for the language.  # noqa: E501

        :param locale: The locale of this GetQuestionnaireDetailsResponseDataQuestionTranslations.  # noqa: E501
        :type: str
        """
        if locale is None:
            raise ValueError("Invalid value for `locale`, must not be `None`")  # noqa: E501

        self._locale = locale

    @property
    def question_text(self):
        """Gets the question_text of this GetQuestionnaireDetailsResponseDataQuestionTranslations.  # noqa: E501

        Question text for the language.  # noqa: E501

        :return: The question_text of this GetQuestionnaireDetailsResponseDataQuestionTranslations.  # noqa: E501
        :rtype: str
        """
        return self._question_text

    @question_text.setter
    def question_text(self, question_text):
        """Sets the question_text of this GetQuestionnaireDetailsResponseDataQuestionTranslations.

        Question text for the language.  # noqa: E501

        :param question_text: The question_text of this GetQuestionnaireDetailsResponseDataQuestionTranslations.  # noqa: E501
        :type: str
        """
        if question_text is None:
            raise ValueError("Invalid value for `question_text`, must not be `None`")  # noqa: E501

        self._question_text = question_text

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GetQuestionnaireDetailsResponseDataQuestionTranslations, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetQuestionnaireDetailsResponseDataQuestionTranslations):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa

"""
    jobsync-api

    Job Sync enables the user to manage jobs (view, create, update and delete jobs) in the Phenom database directly from the ATS, with the updates reflected on the career site.  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: shravan.malla@phenompeople.com
    Generated by: phenom
"""

from __future__ import absolute_import

# import apis into sdk package
from phenom.api.jobsync.jobs_api import JobsApi
# import ApiClient
from phenom.commons.api_client import ApiClient
from phenom.commons.configuration import Configuration
# import models into sdk package
from phenom.api.jobsync.models.category import Category
from phenom.api.jobsync.models.custom_error import CustomError
from phenom.api.jobsync.models.empty import Empty
from phenom.api.jobsync.models.error_response import ErrorResponse
from phenom.api.jobsync.models.job_request_dto import JobRequestDTO
from phenom.api.jobsync.models.job_response_dto import JobResponseDTO
from phenom.api.jobsync.models.job_success_response import JobSuccessResponse
from phenom.api.jobsync.models.jobs_list_success_response import JobsListSuccessResponse
from phenom.api.jobsync.models.location_dto import LocationDTO
from phenom.api.jobsync.models.patch_payload import PatchPayload
from phenom.api.jobsync.models.post_payload import PostPayload
from phenom.api.jobsync.models.posting import Posting
from phenom.api.jobsync.models.recruiter import Recruiter



# coding: utf-8

"""
    candidates-api

    The Candidate APIs allows you to add, update and delete candidates.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class CandidateDataCandidateAttachments(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'resume_file_name': 'str',
        'is_created_from_candidates': 'bool',
        'document_type': 'str',
        'attachment_type': 'str'
    }

    attribute_map = {
        'resume_file_name': 'resumeFileName',
        'is_created_from_candidates': 'isCreatedFromCandidates',
        'document_type': 'documentType',
        'attachment_type': 'attachmentType'
    }

    def __init__(self, resume_file_name=None, is_created_from_candidates=None, document_type=None, attachment_type=None):  # noqa: E501
        """CandidateDataCandidateAttachments - a model defined in Swagger"""  # noqa: E501
        self._resume_file_name = None
        self._is_created_from_candidates = None
        self._document_type = None
        self._attachment_type = None
        self.discriminator = None
        if resume_file_name is not None:
            self.resume_file_name = resume_file_name
        if is_created_from_candidates is not None:
            self.is_created_from_candidates = is_created_from_candidates
        if document_type is not None:
            self.document_type = document_type
        if attachment_type is not None:
            self.attachment_type = attachment_type

    @property
    def resume_file_name(self):
        """Gets the resume_file_name of this CandidateDataCandidateAttachments.  # noqa: E501

        Name of the resume file.  # noqa: E501

        :return: The resume_file_name of this CandidateDataCandidateAttachments.  # noqa: E501
        :rtype: str
        """
        return self._resume_file_name

    @resume_file_name.setter
    def resume_file_name(self, resume_file_name):
        """Sets the resume_file_name of this CandidateDataCandidateAttachments.

        Name of the resume file.  # noqa: E501

        :param resume_file_name: The resume_file_name of this CandidateDataCandidateAttachments.  # noqa: E501
        :type: str
        """

        self._resume_file_name = resume_file_name

    @property
    def is_created_from_candidates(self):
        """Gets the is_created_from_candidates of this CandidateDataCandidateAttachments.  # noqa: E501

        Indicates whether the attachment is created from candidates.  # noqa: E501

        :return: The is_created_from_candidates of this CandidateDataCandidateAttachments.  # noqa: E501
        :rtype: bool
        """
        return self._is_created_from_candidates

    @is_created_from_candidates.setter
    def is_created_from_candidates(self, is_created_from_candidates):
        """Sets the is_created_from_candidates of this CandidateDataCandidateAttachments.

        Indicates whether the attachment is created from candidates.  # noqa: E501

        :param is_created_from_candidates: The is_created_from_candidates of this CandidateDataCandidateAttachments.  # noqa: E501
        :type: bool
        """

        self._is_created_from_candidates = is_created_from_candidates

    @property
    def document_type(self):
        """Gets the document_type of this CandidateDataCandidateAttachments.  # noqa: E501

        Type of the document.  # noqa: E501

        :return: The document_type of this CandidateDataCandidateAttachments.  # noqa: E501
        :rtype: str
        """
        return self._document_type

    @document_type.setter
    def document_type(self, document_type):
        """Sets the document_type of this CandidateDataCandidateAttachments.

        Type of the document.  # noqa: E501

        :param document_type: The document_type of this CandidateDataCandidateAttachments.  # noqa: E501
        :type: str
        """

        self._document_type = document_type

    @property
    def attachment_type(self):
        """Gets the attachment_type of this CandidateDataCandidateAttachments.  # noqa: E501

        Type of the attachment.  # noqa: E501

        :return: The attachment_type of this CandidateDataCandidateAttachments.  # noqa: E501
        :rtype: str
        """
        return self._attachment_type

    @attachment_type.setter
    def attachment_type(self, attachment_type):
        """Sets the attachment_type of this CandidateDataCandidateAttachments.

        Type of the attachment.  # noqa: E501

        :param attachment_type: The attachment_type of this CandidateDataCandidateAttachments.  # noqa: E501
        :type: str
        """

        self._attachment_type = attachment_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CandidateDataCandidateAttachments, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CandidateDataCandidateAttachments):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    projects-api

    These APIs allows you to create workflow statuses, which are then assigned to workflows. These workflows, containing multiple statuses, are subsequently linked to projects. Additionally, candidates are associated with projects, defining the path they are meant to follow within the established workflows.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class GetProjectActivitiesResponseData(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'recruiters_user_id': 'str',
        'candidate_id': 'str',
        'project_name': 'str',
        'project_id': 'str',
        'action_type': 'str',
        'action_value': 'str',
        'created_date': 'str',
        'scope_attr': 'GetProjectActivitiesResponseScopeAttr',
        'recruiter_name': 'str'
    }

    attribute_map = {
        'recruiters_user_id': 'recruitersUserId',
        'candidate_id': 'candidateId',
        'project_name': 'projectName',
        'project_id': 'projectId',
        'action_type': 'actionType',
        'action_value': 'actionValue',
        'created_date': 'createdDate',
        'scope_attr': 'scopeAttr',
        'recruiter_name': 'recruiterName'
    }

    def __init__(self, recruiters_user_id=None, candidate_id=None, project_name=None, project_id=None, action_type=None, action_value=None, created_date=None, scope_attr=None, recruiter_name=None):  # noqa: E501
        """GetProjectActivitiesResponseData - a model defined in Swagger"""  # noqa: E501
        self._recruiters_user_id = None
        self._candidate_id = None
        self._project_name = None
        self._project_id = None
        self._action_type = None
        self._action_value = None
        self._created_date = None
        self._scope_attr = None
        self._recruiter_name = None
        self.discriminator = None
        self.recruiters_user_id = recruiters_user_id
        self.candidate_id = candidate_id
        self.project_name = project_name
        self.project_id = project_id
        self.action_type = action_type
        self.action_value = action_value
        self.created_date = created_date
        self.scope_attr = scope_attr
        self.recruiter_name = recruiter_name

    @property
    def recruiters_user_id(self):
        """Gets the recruiters_user_id of this GetProjectActivitiesResponseData.  # noqa: E501

        User ID of the recruiter.  # noqa: E501

        :return: The recruiters_user_id of this GetProjectActivitiesResponseData.  # noqa: E501
        :rtype: str
        """
        return self._recruiters_user_id

    @recruiters_user_id.setter
    def recruiters_user_id(self, recruiters_user_id):
        """Sets the recruiters_user_id of this GetProjectActivitiesResponseData.

        User ID of the recruiter.  # noqa: E501

        :param recruiters_user_id: The recruiters_user_id of this GetProjectActivitiesResponseData.  # noqa: E501
        :type: str
        """
        if recruiters_user_id is None:
            raise ValueError("Invalid value for `recruiters_user_id`, must not be `None`")  # noqa: E501

        self._recruiters_user_id = recruiters_user_id

    @property
    def candidate_id(self):
        """Gets the candidate_id of this GetProjectActivitiesResponseData.  # noqa: E501

        ID of the candidate.  # noqa: E501

        :return: The candidate_id of this GetProjectActivitiesResponseData.  # noqa: E501
        :rtype: str
        """
        return self._candidate_id

    @candidate_id.setter
    def candidate_id(self, candidate_id):
        """Sets the candidate_id of this GetProjectActivitiesResponseData.

        ID of the candidate.  # noqa: E501

        :param candidate_id: The candidate_id of this GetProjectActivitiesResponseData.  # noqa: E501
        :type: str
        """
        if candidate_id is None:
            raise ValueError("Invalid value for `candidate_id`, must not be `None`")  # noqa: E501

        self._candidate_id = candidate_id

    @property
    def project_name(self):
        """Gets the project_name of this GetProjectActivitiesResponseData.  # noqa: E501

        Name of the project.  # noqa: E501

        :return: The project_name of this GetProjectActivitiesResponseData.  # noqa: E501
        :rtype: str
        """
        return self._project_name

    @project_name.setter
    def project_name(self, project_name):
        """Sets the project_name of this GetProjectActivitiesResponseData.

        Name of the project.  # noqa: E501

        :param project_name: The project_name of this GetProjectActivitiesResponseData.  # noqa: E501
        :type: str
        """
        if project_name is None:
            raise ValueError("Invalid value for `project_name`, must not be `None`")  # noqa: E501

        self._project_name = project_name

    @property
    def project_id(self):
        """Gets the project_id of this GetProjectActivitiesResponseData.  # noqa: E501

        ID of the project.  # noqa: E501

        :return: The project_id of this GetProjectActivitiesResponseData.  # noqa: E501
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this GetProjectActivitiesResponseData.

        ID of the project.  # noqa: E501

        :param project_id: The project_id of this GetProjectActivitiesResponseData.  # noqa: E501
        :type: str
        """
        if project_id is None:
            raise ValueError("Invalid value for `project_id`, must not be `None`")  # noqa: E501

        self._project_id = project_id

    @property
    def action_type(self):
        """Gets the action_type of this GetProjectActivitiesResponseData.  # noqa: E501

        Type of the action.  # noqa: E501

        :return: The action_type of this GetProjectActivitiesResponseData.  # noqa: E501
        :rtype: str
        """
        return self._action_type

    @action_type.setter
    def action_type(self, action_type):
        """Sets the action_type of this GetProjectActivitiesResponseData.

        Type of the action.  # noqa: E501

        :param action_type: The action_type of this GetProjectActivitiesResponseData.  # noqa: E501
        :type: str
        """
        if action_type is None:
            raise ValueError("Invalid value for `action_type`, must not be `None`")  # noqa: E501

        self._action_type = action_type

    @property
    def action_value(self):
        """Gets the action_value of this GetProjectActivitiesResponseData.  # noqa: E501

        Value associated with the action.  # noqa: E501

        :return: The action_value of this GetProjectActivitiesResponseData.  # noqa: E501
        :rtype: str
        """
        return self._action_value

    @action_value.setter
    def action_value(self, action_value):
        """Sets the action_value of this GetProjectActivitiesResponseData.

        Value associated with the action.  # noqa: E501

        :param action_value: The action_value of this GetProjectActivitiesResponseData.  # noqa: E501
        :type: str
        """
        if action_value is None:
            raise ValueError("Invalid value for `action_value`, must not be `None`")  # noqa: E501

        self._action_value = action_value

    @property
    def created_date(self):
        """Gets the created_date of this GetProjectActivitiesResponseData.  # noqa: E501

        Timestamp of when the activity was created.  # noqa: E501

        :return: The created_date of this GetProjectActivitiesResponseData.  # noqa: E501
        :rtype: str
        """
        return self._created_date

    @created_date.setter
    def created_date(self, created_date):
        """Sets the created_date of this GetProjectActivitiesResponseData.

        Timestamp of when the activity was created.  # noqa: E501

        :param created_date: The created_date of this GetProjectActivitiesResponseData.  # noqa: E501
        :type: str
        """
        if created_date is None:
            raise ValueError("Invalid value for `created_date`, must not be `None`")  # noqa: E501

        self._created_date = created_date

    @property
    def scope_attr(self):
        """Gets the scope_attr of this GetProjectActivitiesResponseData.  # noqa: E501


        :return: The scope_attr of this GetProjectActivitiesResponseData.  # noqa: E501
        :rtype: GetProjectActivitiesResponseScopeAttr
        """
        return self._scope_attr

    @scope_attr.setter
    def scope_attr(self, scope_attr):
        """Sets the scope_attr of this GetProjectActivitiesResponseData.


        :param scope_attr: The scope_attr of this GetProjectActivitiesResponseData.  # noqa: E501
        :type: GetProjectActivitiesResponseScopeAttr
        """
        if scope_attr is None:
            raise ValueError("Invalid value for `scope_attr`, must not be `None`")  # noqa: E501

        self._scope_attr = scope_attr

    @property
    def recruiter_name(self):
        """Gets the recruiter_name of this GetProjectActivitiesResponseData.  # noqa: E501

        Name of the recruiter.  # noqa: E501

        :return: The recruiter_name of this GetProjectActivitiesResponseData.  # noqa: E501
        :rtype: str
        """
        return self._recruiter_name

    @recruiter_name.setter
    def recruiter_name(self, recruiter_name):
        """Sets the recruiter_name of this GetProjectActivitiesResponseData.

        Name of the recruiter.  # noqa: E501

        :param recruiter_name: The recruiter_name of this GetProjectActivitiesResponseData.  # noqa: E501
        :type: str
        """
        if recruiter_name is None:
            raise ValueError("Invalid value for `recruiter_name`, must not be `None`")  # noqa: E501

        self._recruiter_name = recruiter_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GetProjectActivitiesResponseData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetProjectActivitiesResponseData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa

"""
    servicehub-scim-api

    API endpoints for user management, utilizing the SCIM protocol.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

from __future__ import absolute_import

# import apis into sdk package
from phenom.api.servicehubscim.scim_api import SCIMApi
# import ApiClient
from phenom.commons.api_client import ApiClient
from phenom.commons.configuration import Configuration
# import models into sdk package
from phenom.api.servicehubscim.models.error_response import ErrorResponse
from phenom.api.servicehubscim.models.scim_group_list import ScimGroupList
from phenom.api.servicehubscim.models.scim_group_list_meta import ScimGroupListMeta
from phenom.api.servicehubscim.models.scim_group_list_resources import ScimGroupListResources
from phenom.api.servicehubscim.models.scim_patch_request import ScimPatchRequest
from phenom.api.servicehubscim.models.scim_patch_request_operations import ScimPatchRequestOperations
from phenom.api.servicehubscim.models.scim_role_list import ScimRoleList
from phenom.api.servicehubscim.models.scim_role_list_meta import ScimRoleListMeta
from phenom.api.servicehubscim.models.scim_role_list_resources import ScimRoleListResources
from phenom.api.servicehubscim.models.scim_user import ScimUser
from phenom.api.servicehubscim.models.scim_user_addresses import ScimUserAddresses
from phenom.api.servicehubscim.models.scim_user_emails import ScimUserEmails
from phenom.api.servicehubscim.models.scim_user_entitlements import ScimUserEntitlements
from phenom.api.servicehubscim.models.scim_user_groups import ScimUserGroups
from phenom.api.servicehubscim.models.scim_user_list import ScimUserList
from phenom.api.servicehubscim.models.scim_user_list_meta import ScimUserListMeta
from phenom.api.servicehubscim.models.scim_user_name import ScimUserName
from phenom.api.servicehubscim.models.scim_user_phone_numbers import ScimUserPhoneNumbers
from phenom.api.servicehubscim.models.scim_user_photos import ScimUserPhotos
from phenom.api.servicehubscim.models.scim_user_roles import ScimUserRoles
from phenom.api.servicehubscim.models.unauthorized_response import UnauthorizedResponse



# coding: utf-8

"""
    projects-api

    These APIs allows you to create workflow statuses, which are then assigned to workflows. These workflows, containing multiple statuses, are subsequently linked to projects. Additionally, candidates are associated with projects, defining the path they are meant to follow within the established workflows.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class GetProjectsResponseMatchingCriteriaDistance(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'min': 'float',
        'max': 'float',
        'unit': 'str'
    }

    attribute_map = {
        'min': 'min',
        'max': 'max',
        'unit': 'unit'
    }

    def __init__(self, min=None, max=None, unit=None):  # noqa: E501
        """GetProjectsResponseMatchingCriteriaDistance - a model defined in Swagger"""  # noqa: E501
        self._min = None
        self._max = None
        self._unit = None
        self.discriminator = None
        if min is not None:
            self.min = min
        if max is not None:
            self.max = max
        if unit is not None:
            self.unit = unit

    @property
    def min(self):
        """Gets the min of this GetProjectsResponseMatchingCriteriaDistance.  # noqa: E501

        The minimum distance for the project.  # noqa: E501

        :return: The min of this GetProjectsResponseMatchingCriteriaDistance.  # noqa: E501
        :rtype: float
        """
        return self._min

    @min.setter
    def min(self, min):
        """Sets the min of this GetProjectsResponseMatchingCriteriaDistance.

        The minimum distance for the project.  # noqa: E501

        :param min: The min of this GetProjectsResponseMatchingCriteriaDistance.  # noqa: E501
        :type: float
        """

        self._min = min

    @property
    def max(self):
        """Gets the max of this GetProjectsResponseMatchingCriteriaDistance.  # noqa: E501

        The maximum distance for the project.  # noqa: E501

        :return: The max of this GetProjectsResponseMatchingCriteriaDistance.  # noqa: E501
        :rtype: float
        """
        return self._max

    @max.setter
    def max(self, max):
        """Sets the max of this GetProjectsResponseMatchingCriteriaDistance.

        The maximum distance for the project.  # noqa: E501

        :param max: The max of this GetProjectsResponseMatchingCriteriaDistance.  # noqa: E501
        :type: float
        """

        self._max = max

    @property
    def unit(self):
        """Gets the unit of this GetProjectsResponseMatchingCriteriaDistance.  # noqa: E501

        The unit of distance for the project (e.g., 'miles').  # noqa: E501

        :return: The unit of this GetProjectsResponseMatchingCriteriaDistance.  # noqa: E501
        :rtype: str
        """
        return self._unit

    @unit.setter
    def unit(self, unit):
        """Sets the unit of this GetProjectsResponseMatchingCriteriaDistance.

        The unit of distance for the project (e.g., 'miles').  # noqa: E501

        :param unit: The unit of this GetProjectsResponseMatchingCriteriaDistance.  # noqa: E501
        :type: str
        """

        self._unit = unit

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GetProjectsResponseMatchingCriteriaDistance, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetProjectsResponseMatchingCriteriaDistance):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa
"""
    search-api

    These APIs helps to search and suggest based on keyword among available jobs.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

from __future__ import absolute_import

# import models into model package
from phenom.api.search.models.bad_request import BadRequest
from phenom.api.search.models.error_response import ErrorResponse
from phenom.api.search.models.job_node import JobNode
from phenom.api.search.models.job_search_request import JobSearchRequest
from phenom.api.search.models.job_search_request_facets import JobSearchRequestFacets
from phenom.api.search.models.job_search_response import JobSearchResponse
from phenom.api.search.models.job_search_response_data import JobSearchResponseData
from phenom.api.search.models.job_titles_response import JobTitlesResponse
from phenom.api.search.models.job_titles_response_data import JobTitlesResponseData
from phenom.api.search.models.job_titles_response_data_titles import JobTitlesResponseDataTitles
from phenom.api.search.models.location_data import LocationData



# coding: utf-8

"""
    candidates-api-activities

    The Note APIs allows you to Add, Get, Update and Delete Notes.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class GetNoteActivitiesData(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'recruiters_user_id': 'str',
        'action_type': 'str',
        'created_date': 'str',
        'candidate_id': 'str',
        'action_value': 'str',
        'added_new_value': 'str',
        'scope_attr': 'GetNoteActivitiesScopeAttr',
        'recruiter_name': 'str'
    }

    attribute_map = {
        'recruiters_user_id': 'recruitersUserId',
        'action_type': 'actionType',
        'created_date': 'createdDate',
        'candidate_id': 'candidateId',
        'action_value': 'actionValue',
        'added_new_value': 'addedNewValue',
        'scope_attr': 'scopeAttr',
        'recruiter_name': 'recruiterName'
    }

    def __init__(self, recruiters_user_id=None, action_type=None, created_date=None, candidate_id=None, action_value=None, added_new_value=None, scope_attr=None, recruiter_name=None):  # noqa: E501
        """GetNoteActivitiesData - a model defined in Swagger"""  # noqa: E501
        self._recruiters_user_id = None
        self._action_type = None
        self._created_date = None
        self._candidate_id = None
        self._action_value = None
        self._added_new_value = None
        self._scope_attr = None
        self._recruiter_name = None
        self.discriminator = None
        self.recruiters_user_id = recruiters_user_id
        self.action_type = action_type
        self.created_date = created_date
        self.candidate_id = candidate_id
        self.action_value = action_value
        self.added_new_value = added_new_value
        self.scope_attr = scope_attr
        self.recruiter_name = recruiter_name

    @property
    def recruiters_user_id(self):
        """Gets the recruiters_user_id of this GetNoteActivitiesData.  # noqa: E501

        The user ID of the recruiter associated with the activity.  # noqa: E501

        :return: The recruiters_user_id of this GetNoteActivitiesData.  # noqa: E501
        :rtype: str
        """
        return self._recruiters_user_id

    @recruiters_user_id.setter
    def recruiters_user_id(self, recruiters_user_id):
        """Sets the recruiters_user_id of this GetNoteActivitiesData.

        The user ID of the recruiter associated with the activity.  # noqa: E501

        :param recruiters_user_id: The recruiters_user_id of this GetNoteActivitiesData.  # noqa: E501
        :type: str
        """
        if recruiters_user_id is None:
            raise ValueError("Invalid value for `recruiters_user_id`, must not be `None`")  # noqa: E501

        self._recruiters_user_id = recruiters_user_id

    @property
    def action_type(self):
        """Gets the action_type of this GetNoteActivitiesData.  # noqa: E501

        The type of action performed, such as 'create', 'update', or 'delete'.  # noqa: E501

        :return: The action_type of this GetNoteActivitiesData.  # noqa: E501
        :rtype: str
        """
        return self._action_type

    @action_type.setter
    def action_type(self, action_type):
        """Sets the action_type of this GetNoteActivitiesData.

        The type of action performed, such as 'create', 'update', or 'delete'.  # noqa: E501

        :param action_type: The action_type of this GetNoteActivitiesData.  # noqa: E501
        :type: str
        """
        if action_type is None:
            raise ValueError("Invalid value for `action_type`, must not be `None`")  # noqa: E501

        self._action_type = action_type

    @property
    def created_date(self):
        """Gets the created_date of this GetNoteActivitiesData.  # noqa: E501

        The timestamp when the activity was created.  # noqa: E501

        :return: The created_date of this GetNoteActivitiesData.  # noqa: E501
        :rtype: str
        """
        return self._created_date

    @created_date.setter
    def created_date(self, created_date):
        """Sets the created_date of this GetNoteActivitiesData.

        The timestamp when the activity was created.  # noqa: E501

        :param created_date: The created_date of this GetNoteActivitiesData.  # noqa: E501
        :type: str
        """
        if created_date is None:
            raise ValueError("Invalid value for `created_date`, must not be `None`")  # noqa: E501

        self._created_date = created_date

    @property
    def candidate_id(self):
        """Gets the candidate_id of this GetNoteActivitiesData.  # noqa: E501

        The ID of the candidate related to the activity.  # noqa: E501

        :return: The candidate_id of this GetNoteActivitiesData.  # noqa: E501
        :rtype: str
        """
        return self._candidate_id

    @candidate_id.setter
    def candidate_id(self, candidate_id):
        """Sets the candidate_id of this GetNoteActivitiesData.

        The ID of the candidate related to the activity.  # noqa: E501

        :param candidate_id: The candidate_id of this GetNoteActivitiesData.  # noqa: E501
        :type: str
        """
        if candidate_id is None:
            raise ValueError("Invalid value for `candidate_id`, must not be `None`")  # noqa: E501

        self._candidate_id = candidate_id

    @property
    def action_value(self):
        """Gets the action_value of this GetNoteActivitiesData.  # noqa: E501

        The value associated with the action.  # noqa: E501

        :return: The action_value of this GetNoteActivitiesData.  # noqa: E501
        :rtype: str
        """
        return self._action_value

    @action_value.setter
    def action_value(self, action_value):
        """Sets the action_value of this GetNoteActivitiesData.

        The value associated with the action.  # noqa: E501

        :param action_value: The action_value of this GetNoteActivitiesData.  # noqa: E501
        :type: str
        """
        if action_value is None:
            raise ValueError("Invalid value for `action_value`, must not be `None`")  # noqa: E501

        self._action_value = action_value

    @property
    def added_new_value(self):
        """Gets the added_new_value of this GetNoteActivitiesData.  # noqa: E501

        The new value added during the update action.  # noqa: E501

        :return: The added_new_value of this GetNoteActivitiesData.  # noqa: E501
        :rtype: str
        """
        return self._added_new_value

    @added_new_value.setter
    def added_new_value(self, added_new_value):
        """Sets the added_new_value of this GetNoteActivitiesData.

        The new value added during the update action.  # noqa: E501

        :param added_new_value: The added_new_value of this GetNoteActivitiesData.  # noqa: E501
        :type: str
        """
        if added_new_value is None:
            raise ValueError("Invalid value for `added_new_value`, must not be `None`")  # noqa: E501

        self._added_new_value = added_new_value

    @property
    def scope_attr(self):
        """Gets the scope_attr of this GetNoteActivitiesData.  # noqa: E501


        :return: The scope_attr of this GetNoteActivitiesData.  # noqa: E501
        :rtype: GetNoteActivitiesScopeAttr
        """
        return self._scope_attr

    @scope_attr.setter
    def scope_attr(self, scope_attr):
        """Sets the scope_attr of this GetNoteActivitiesData.


        :param scope_attr: The scope_attr of this GetNoteActivitiesData.  # noqa: E501
        :type: GetNoteActivitiesScopeAttr
        """
        if scope_attr is None:
            raise ValueError("Invalid value for `scope_attr`, must not be `None`")  # noqa: E501

        self._scope_attr = scope_attr

    @property
    def recruiter_name(self):
        """Gets the recruiter_name of this GetNoteActivitiesData.  # noqa: E501

        The name of the recruiter associated with the activity.  # noqa: E501

        :return: The recruiter_name of this GetNoteActivitiesData.  # noqa: E501
        :rtype: str
        """
        return self._recruiter_name

    @recruiter_name.setter
    def recruiter_name(self, recruiter_name):
        """Sets the recruiter_name of this GetNoteActivitiesData.

        The name of the recruiter associated with the activity.  # noqa: E501

        :param recruiter_name: The recruiter_name of this GetNoteActivitiesData.  # noqa: E501
        :type: str
        """
        if recruiter_name is None:
            raise ValueError("Invalid value for `recruiter_name`, must not be `None`")  # noqa: E501

        self._recruiter_name = recruiter_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GetNoteActivitiesData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetNoteActivitiesData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    employees-api-careerpath

    The Employee upskill APIs are related to the career pathing that an employee can use them for upskilling in an organisation.  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@phenompeople.com
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class CurrentJobProfile(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'job_title': 'str',
        'job_profile_id': 'str'
    }

    attribute_map = {
        'job_title': 'jobTitle',
        'job_profile_id': 'jobProfileId'
    }

    def __init__(self, job_title='Software Developer', job_profile_id='POS30003965'):  # noqa: E501
        """CurrentJobProfile - a model defined in Swagger"""  # noqa: E501
        self._job_title = None
        self._job_profile_id = None
        self.discriminator = None
        if job_title is not None:
            self.job_title = job_title
        if job_profile_id is not None:
            self.job_profile_id = job_profile_id

    @property
    def job_title(self):
        """Gets the job_title of this CurrentJobProfile.  # noqa: E501

        Job Title of the current job position.  # noqa: E501

        :return: The job_title of this CurrentJobProfile.  # noqa: E501
        :rtype: str
        """
        return self._job_title

    @job_title.setter
    def job_title(self, job_title):
        """Sets the job_title of this CurrentJobProfile.

        Job Title of the current job position.  # noqa: E501

        :param job_title: The job_title of this CurrentJobProfile.  # noqa: E501
        :type: str
        """

        self._job_title = job_title

    @property
    def job_profile_id(self):
        """Gets the job_profile_id of this CurrentJobProfile.  # noqa: E501

        JobProfileId- unique field to identify the job position.  # noqa: E501

        :return: The job_profile_id of this CurrentJobProfile.  # noqa: E501
        :rtype: str
        """
        return self._job_profile_id

    @job_profile_id.setter
    def job_profile_id(self, job_profile_id):
        """Sets the job_profile_id of this CurrentJobProfile.

        JobProfileId- unique field to identify the job position.  # noqa: E501

        :param job_profile_id: The job_profile_id of this CurrentJobProfile.  # noqa: E501
        :type: str
        """

        self._job_profile_id = job_profile_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CurrentJobProfile, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CurrentJobProfile):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    apply-api

    The Apply API allows for seamless integration of the Phenom systems, enabling partners to push applications directly. This API also enables partners to integrate the Phenom Quick application process into their own job boards, while still maintaining control over the candidate experience. As a result, candidates can submit their applications without needing to visit the customer career site.  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class Resume(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'file_content': 'str',
        'file_name': 'str',
        'content_type_id': 'str'
    }

    attribute_map = {
        'file_content': 'fileContent',
        'file_name': 'fileName',
        'content_type_id': 'contentTypeId'
    }

    def __init__(self, file_content=None, file_name=None, content_type_id=None):  # noqa: E501
        """Resume - a model defined in Swagger"""  # noqa: E501
        self._file_content = None
        self._file_name = None
        self._content_type_id = None
        self.discriminator = None
        self.file_content = file_content
        self.file_name = file_name
        if content_type_id is not None:
            self.content_type_id = content_type_id

    @property
    def file_content(self):
        """Gets the file_content of this Resume.  # noqa: E501

        File Content in base64 format.  # noqa: E501

        :return: The file_content of this Resume.  # noqa: E501
        :rtype: str
        """
        return self._file_content

    @file_content.setter
    def file_content(self, file_content):
        """Sets the file_content of this Resume.

        File Content in base64 format.  # noqa: E501

        :param file_content: The file_content of this Resume.  # noqa: E501
        :type: str
        """
        if file_content is None:
            raise ValueError("Invalid value for `file_content`, must not be `None`")  # noqa: E501

        self._file_content = file_content

    @property
    def file_name(self):
        """Gets the file_name of this Resume.  # noqa: E501

        Name of the file.  # noqa: E501

        :return: The file_name of this Resume.  # noqa: E501
        :rtype: str
        """
        return self._file_name

    @file_name.setter
    def file_name(self, file_name):
        """Sets the file_name of this Resume.

        Name of the file.  # noqa: E501

        :param file_name: The file_name of this Resume.  # noqa: E501
        :type: str
        """
        if file_name is None:
            raise ValueError("Invalid value for `file_name`, must not be `None`")  # noqa: E501

        self._file_name = file_name

    @property
    def content_type_id(self):
        """Gets the content_type_id of this Resume.  # noqa: E501

        (Optional) Any id to identify the content type of the file.  # noqa: E501

        :return: The content_type_id of this Resume.  # noqa: E501
        :rtype: str
        """
        return self._content_type_id

    @content_type_id.setter
    def content_type_id(self, content_type_id):
        """Sets the content_type_id of this Resume.

        (Optional) Any id to identify the content type of the file.  # noqa: E501

        :param content_type_id: The content_type_id of this Resume.  # noqa: E501
        :type: str
        """

        self._content_type_id = content_type_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Resume, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Resume):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    evaluation-api

    Hiring Manager can view all the pending tasks and evaluate the interview if any pending interviews.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class CandidateJobEvaluationRequest(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'rating': 'float',
        'recommendation': 'str',
        'current_status': 'str',
        'previous_status': 'str',
        'new_note_display_text': 'str',
        'new_note_text': 'str',
        'tagged_recruiters': 'list[str]',
        'form_id': 'str',
        'form_name': 'str',
        'is_rejected': 'bool'
    }

    attribute_map = {
        'rating': 'rating',
        'recommendation': 'recommendation',
        'current_status': 'currentStatus',
        'previous_status': 'previousStatus',
        'new_note_display_text': 'newNoteDisplayText',
        'new_note_text': 'newNoteText',
        'tagged_recruiters': 'taggedRecruiters',
        'form_id': 'formId',
        'form_name': 'formName',
        'is_rejected': 'isRejected'
    }

    def __init__(self, rating=None, recommendation=None, current_status=None, previous_status=None, new_note_display_text=None, new_note_text=None, tagged_recruiters=None, form_id=None, form_name=None, is_rejected=False):  # noqa: E501
        """CandidateJobEvaluationRequest - a model defined in Swagger"""  # noqa: E501
        self._rating = None
        self._recommendation = None
        self._current_status = None
        self._previous_status = None
        self._new_note_display_text = None
        self._new_note_text = None
        self._tagged_recruiters = None
        self._form_id = None
        self._form_name = None
        self._is_rejected = None
        self.discriminator = None
        if rating is not None:
            self.rating = rating
        if recommendation is not None:
            self.recommendation = recommendation
        if current_status is not None:
            self.current_status = current_status
        if previous_status is not None:
            self.previous_status = previous_status
        if new_note_display_text is not None:
            self.new_note_display_text = new_note_display_text
        if new_note_text is not None:
            self.new_note_text = new_note_text
        if tagged_recruiters is not None:
            self.tagged_recruiters = tagged_recruiters
        if form_id is not None:
            self.form_id = form_id
        if form_name is not None:
            self.form_name = form_name
        if is_rejected is not None:
            self.is_rejected = is_rejected

    @property
    def rating(self):
        """Gets the rating of this CandidateJobEvaluationRequest.  # noqa: E501

        Candidate rating based on the provided evaluation.  # noqa: E501

        :return: The rating of this CandidateJobEvaluationRequest.  # noqa: E501
        :rtype: float
        """
        return self._rating

    @rating.setter
    def rating(self, rating):
        """Sets the rating of this CandidateJobEvaluationRequest.

        Candidate rating based on the provided evaluation.  # noqa: E501

        :param rating: The rating of this CandidateJobEvaluationRequest.  # noqa: E501
        :type: float
        """

        self._rating = rating

    @property
    def recommendation(self):
        """Gets the recommendation of this CandidateJobEvaluationRequest.  # noqa: E501

        Recommendation of the candidate based on given evaluation.  # noqa: E501

        :return: The recommendation of this CandidateJobEvaluationRequest.  # noqa: E501
        :rtype: str
        """
        return self._recommendation

    @recommendation.setter
    def recommendation(self, recommendation):
        """Sets the recommendation of this CandidateJobEvaluationRequest.

        Recommendation of the candidate based on given evaluation.  # noqa: E501

        :param recommendation: The recommendation of this CandidateJobEvaluationRequest.  # noqa: E501
        :type: str
        """

        self._recommendation = recommendation

    @property
    def current_status(self):
        """Gets the current_status of this CandidateJobEvaluationRequest.  # noqa: E501

        Current status of the candidate based on given evaluation.  # noqa: E501

        :return: The current_status of this CandidateJobEvaluationRequest.  # noqa: E501
        :rtype: str
        """
        return self._current_status

    @current_status.setter
    def current_status(self, current_status):
        """Sets the current_status of this CandidateJobEvaluationRequest.

        Current status of the candidate based on given evaluation.  # noqa: E501

        :param current_status: The current_status of this CandidateJobEvaluationRequest.  # noqa: E501
        :type: str
        """

        self._current_status = current_status

    @property
    def previous_status(self):
        """Gets the previous_status of this CandidateJobEvaluationRequest.  # noqa: E501

        Previous status of the candidate before this evaluation.  # noqa: E501

        :return: The previous_status of this CandidateJobEvaluationRequest.  # noqa: E501
        :rtype: str
        """
        return self._previous_status

    @previous_status.setter
    def previous_status(self, previous_status):
        """Sets the previous_status of this CandidateJobEvaluationRequest.

        Previous status of the candidate before this evaluation.  # noqa: E501

        :param previous_status: The previous_status of this CandidateJobEvaluationRequest.  # noqa: E501
        :type: str
        """

        self._previous_status = previous_status

    @property
    def new_note_display_text(self):
        """Gets the new_note_display_text of this CandidateJobEvaluationRequest.  # noqa: E501

        Note added by evaluator.  # noqa: E501

        :return: The new_note_display_text of this CandidateJobEvaluationRequest.  # noqa: E501
        :rtype: str
        """
        return self._new_note_display_text

    @new_note_display_text.setter
    def new_note_display_text(self, new_note_display_text):
        """Sets the new_note_display_text of this CandidateJobEvaluationRequest.

        Note added by evaluator.  # noqa: E501

        :param new_note_display_text: The new_note_display_text of this CandidateJobEvaluationRequest.  # noqa: E501
        :type: str
        """

        self._new_note_display_text = new_note_display_text

    @property
    def new_note_text(self):
        """Gets the new_note_text of this CandidateJobEvaluationRequest.  # noqa: E501

        Note added by evaluator.  # noqa: E501

        :return: The new_note_text of this CandidateJobEvaluationRequest.  # noqa: E501
        :rtype: str
        """
        return self._new_note_text

    @new_note_text.setter
    def new_note_text(self, new_note_text):
        """Sets the new_note_text of this CandidateJobEvaluationRequest.

        Note added by evaluator.  # noqa: E501

        :param new_note_text: The new_note_text of this CandidateJobEvaluationRequest.  # noqa: E501
        :type: str
        """

        self._new_note_text = new_note_text

    @property
    def tagged_recruiters(self):
        """Gets the tagged_recruiters of this CandidateJobEvaluationRequest.  # noqa: E501

        List of tagged recruiters.  # noqa: E501

        :return: The tagged_recruiters of this CandidateJobEvaluationRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._tagged_recruiters

    @tagged_recruiters.setter
    def tagged_recruiters(self, tagged_recruiters):
        """Sets the tagged_recruiters of this CandidateJobEvaluationRequest.

        List of tagged recruiters.  # noqa: E501

        :param tagged_recruiters: The tagged_recruiters of this CandidateJobEvaluationRequest.  # noqa: E501
        :type: list[str]
        """

        self._tagged_recruiters = tagged_recruiters

    @property
    def form_id(self):
        """Gets the form_id of this CandidateJobEvaluationRequest.  # noqa: E501

        Id of the evaluation form.  # noqa: E501

        :return: The form_id of this CandidateJobEvaluationRequest.  # noqa: E501
        :rtype: str
        """
        return self._form_id

    @form_id.setter
    def form_id(self, form_id):
        """Sets the form_id of this CandidateJobEvaluationRequest.

        Id of the evaluation form.  # noqa: E501

        :param form_id: The form_id of this CandidateJobEvaluationRequest.  # noqa: E501
        :type: str
        """

        self._form_id = form_id

    @property
    def form_name(self):
        """Gets the form_name of this CandidateJobEvaluationRequest.  # noqa: E501

        Name of the evaluation form.  # noqa: E501

        :return: The form_name of this CandidateJobEvaluationRequest.  # noqa: E501
        :rtype: str
        """
        return self._form_name

    @form_name.setter
    def form_name(self, form_name):
        """Sets the form_name of this CandidateJobEvaluationRequest.

        Name of the evaluation form.  # noqa: E501

        :param form_name: The form_name of this CandidateJobEvaluationRequest.  # noqa: E501
        :type: str
        """

        self._form_name = form_name

    @property
    def is_rejected(self):
        """Gets the is_rejected of this CandidateJobEvaluationRequest.  # noqa: E501

        Candidate is rejected (true or false).  # noqa: E501

        :return: The is_rejected of this CandidateJobEvaluationRequest.  # noqa: E501
        :rtype: bool
        """
        return self._is_rejected

    @is_rejected.setter
    def is_rejected(self, is_rejected):
        """Sets the is_rejected of this CandidateJobEvaluationRequest.

        Candidate is rejected (true or false).  # noqa: E501

        :param is_rejected: The is_rejected of this CandidateJobEvaluationRequest.  # noqa: E501
        :type: bool
        """

        self._is_rejected = is_rejected

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CandidateJobEvaluationRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CandidateJobEvaluationRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    projects-api

    These APIs allows you to create workflow statuses, which are then assigned to workflows. These workflows, containing multiple statuses, are subsequently linked to projects. Additionally, candidates are associated with projects, defining the path they are meant to follow within the established workflows.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class GetWorkflowResponseStages(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'status_code': 'str',
        'status_id': 'str',
        'further_transition_stages': 'list[GetWorkflowResponseFurtherTransitionStages]',
        'is_rejection_stage': 'bool',
        'is_final_stage': 'bool',
        'is_deleted_stage': 'bool'
    }

    attribute_map = {
        'name': 'name',
        'status_code': 'statusCode',
        'status_id': 'statusId',
        'further_transition_stages': 'furtherTransitionStages',
        'is_rejection_stage': 'isRejectionStage',
        'is_final_stage': 'isFinalStage',
        'is_deleted_stage': 'isDeletedStage'
    }

    def __init__(self, name=None, status_code=None, status_id=None, further_transition_stages=None, is_rejection_stage=None, is_final_stage=None, is_deleted_stage=None):  # noqa: E501
        """GetWorkflowResponseStages - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._status_code = None
        self._status_id = None
        self._further_transition_stages = None
        self._is_rejection_stage = None
        self._is_final_stage = None
        self._is_deleted_stage = None
        self.discriminator = None
        self.name = name
        self.status_code = status_code
        self.status_id = status_id
        self.further_transition_stages = further_transition_stages
        self.is_rejection_stage = is_rejection_stage
        self.is_final_stage = is_final_stage
        self.is_deleted_stage = is_deleted_stage

    @property
    def name(self):
        """Gets the name of this GetWorkflowResponseStages.  # noqa: E501

        Name of the workflow stage.  # noqa: E501

        :return: The name of this GetWorkflowResponseStages.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this GetWorkflowResponseStages.

        Name of the workflow stage.  # noqa: E501

        :param name: The name of this GetWorkflowResponseStages.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def status_code(self):
        """Gets the status_code of this GetWorkflowResponseStages.  # noqa: E501

        Status code of the workflow stage.  # noqa: E501

        :return: The status_code of this GetWorkflowResponseStages.  # noqa: E501
        :rtype: str
        """
        return self._status_code

    @status_code.setter
    def status_code(self, status_code):
        """Sets the status_code of this GetWorkflowResponseStages.

        Status code of the workflow stage.  # noqa: E501

        :param status_code: The status_code of this GetWorkflowResponseStages.  # noqa: E501
        :type: str
        """
        if status_code is None:
            raise ValueError("Invalid value for `status_code`, must not be `None`")  # noqa: E501

        self._status_code = status_code

    @property
    def status_id(self):
        """Gets the status_id of this GetWorkflowResponseStages.  # noqa: E501

        ID of the workflow stage.  # noqa: E501

        :return: The status_id of this GetWorkflowResponseStages.  # noqa: E501
        :rtype: str
        """
        return self._status_id

    @status_id.setter
    def status_id(self, status_id):
        """Sets the status_id of this GetWorkflowResponseStages.

        ID of the workflow stage.  # noqa: E501

        :param status_id: The status_id of this GetWorkflowResponseStages.  # noqa: E501
        :type: str
        """
        if status_id is None:
            raise ValueError("Invalid value for `status_id`, must not be `None`")  # noqa: E501

        self._status_id = status_id

    @property
    def further_transition_stages(self):
        """Gets the further_transition_stages of this GetWorkflowResponseStages.  # noqa: E501


        :return: The further_transition_stages of this GetWorkflowResponseStages.  # noqa: E501
        :rtype: list[GetWorkflowResponseFurtherTransitionStages]
        """
        return self._further_transition_stages

    @further_transition_stages.setter
    def further_transition_stages(self, further_transition_stages):
        """Sets the further_transition_stages of this GetWorkflowResponseStages.


        :param further_transition_stages: The further_transition_stages of this GetWorkflowResponseStages.  # noqa: E501
        :type: list[GetWorkflowResponseFurtherTransitionStages]
        """
        if further_transition_stages is None:
            raise ValueError("Invalid value for `further_transition_stages`, must not be `None`")  # noqa: E501

        self._further_transition_stages = further_transition_stages

    @property
    def is_rejection_stage(self):
        """Gets the is_rejection_stage of this GetWorkflowResponseStages.  # noqa: E501

        Indicates if the stage is a rejection stage.  # noqa: E501

        :return: The is_rejection_stage of this GetWorkflowResponseStages.  # noqa: E501
        :rtype: bool
        """
        return self._is_rejection_stage

    @is_rejection_stage.setter
    def is_rejection_stage(self, is_rejection_stage):
        """Sets the is_rejection_stage of this GetWorkflowResponseStages.

        Indicates if the stage is a rejection stage.  # noqa: E501

        :param is_rejection_stage: The is_rejection_stage of this GetWorkflowResponseStages.  # noqa: E501
        :type: bool
        """
        if is_rejection_stage is None:
            raise ValueError("Invalid value for `is_rejection_stage`, must not be `None`")  # noqa: E501

        self._is_rejection_stage = is_rejection_stage

    @property
    def is_final_stage(self):
        """Gets the is_final_stage of this GetWorkflowResponseStages.  # noqa: E501

        Indicates if the stage is a final stage.  # noqa: E501

        :return: The is_final_stage of this GetWorkflowResponseStages.  # noqa: E501
        :rtype: bool
        """
        return self._is_final_stage

    @is_final_stage.setter
    def is_final_stage(self, is_final_stage):
        """Sets the is_final_stage of this GetWorkflowResponseStages.

        Indicates if the stage is a final stage.  # noqa: E501

        :param is_final_stage: The is_final_stage of this GetWorkflowResponseStages.  # noqa: E501
        :type: bool
        """
        if is_final_stage is None:
            raise ValueError("Invalid value for `is_final_stage`, must not be `None`")  # noqa: E501

        self._is_final_stage = is_final_stage

    @property
    def is_deleted_stage(self):
        """Gets the is_deleted_stage of this GetWorkflowResponseStages.  # noqa: E501

        Indicates if the stage is deleted.  # noqa: E501

        :return: The is_deleted_stage of this GetWorkflowResponseStages.  # noqa: E501
        :rtype: bool
        """
        return self._is_deleted_stage

    @is_deleted_stage.setter
    def is_deleted_stage(self, is_deleted_stage):
        """Sets the is_deleted_stage of this GetWorkflowResponseStages.

        Indicates if the stage is deleted.  # noqa: E501

        :param is_deleted_stage: The is_deleted_stage of this GetWorkflowResponseStages.  # noqa: E501
        :type: bool
        """
        if is_deleted_stage is None:
            raise ValueError("Invalid value for `is_deleted_stage`, must not be `None`")  # noqa: E501

        self._is_deleted_stage = is_deleted_stage

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GetWorkflowResponseStages, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetWorkflowResponseStages):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    apply-api

    The Apply API allows for seamless integration of the Phenom systems, enabling partners to push applications directly. This API also enables partners to integrate the Phenom Quick application process into their own job boards, while still maintaining control over the candidate experience. As a result, candidates can submit their applications without needing to visit the customer career site.  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class CandidateWithId(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'first_name': 'str',
        'middle_name': 'str',
        'last_name': 'str',
        'contact_data': 'ContactData',
        'address_data': 'AddressData',
        'sms_opt_in': 'bool',
        'experience_data': 'list[ExperienceData]',
        'education_data': 'list[EducationData]',
        'id': 'str'
    }

    attribute_map = {
        'first_name': 'firstName',
        'middle_name': 'middleName',
        'last_name': 'lastName',
        'contact_data': 'contactData',
        'address_data': 'addressData',
        'sms_opt_in': 'smsOptIn',
        'experience_data': 'experienceData',
        'education_data': 'educationData',
        'id': 'id'
    }

    def __init__(self, first_name=None, middle_name=None, last_name=None, contact_data=None, address_data=None, sms_opt_in=None, experience_data=None, education_data=None, id=None):  # noqa: E501
        """CandidateWithId - a model defined in Swagger"""  # noqa: E501
        self._first_name = None
        self._middle_name = None
        self._last_name = None
        self._contact_data = None
        self._address_data = None
        self._sms_opt_in = None
        self._experience_data = None
        self._education_data = None
        self._id = None
        self.discriminator = None
        self.first_name = first_name
        if middle_name is not None:
            self.middle_name = middle_name
        self.last_name = last_name
        if contact_data is not None:
            self.contact_data = contact_data
        if address_data is not None:
            self.address_data = address_data
        if sms_opt_in is not None:
            self.sms_opt_in = sms_opt_in
        if experience_data is not None:
            self.experience_data = experience_data
        if education_data is not None:
            self.education_data = education_data
        if id is not None:
            self.id = id

    @property
    def first_name(self):
        """Gets the first_name of this CandidateWithId.  # noqa: E501

        First Name of the candidate.  # noqa: E501

        :return: The first_name of this CandidateWithId.  # noqa: E501
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """Sets the first_name of this CandidateWithId.

        First Name of the candidate.  # noqa: E501

        :param first_name: The first_name of this CandidateWithId.  # noqa: E501
        :type: str
        """
        if first_name is None:
            raise ValueError("Invalid value for `first_name`, must not be `None`")  # noqa: E501

        self._first_name = first_name

    @property
    def middle_name(self):
        """Gets the middle_name of this CandidateWithId.  # noqa: E501

        Middle Name of the candidate.  # noqa: E501

        :return: The middle_name of this CandidateWithId.  # noqa: E501
        :rtype: str
        """
        return self._middle_name

    @middle_name.setter
    def middle_name(self, middle_name):
        """Sets the middle_name of this CandidateWithId.

        Middle Name of the candidate.  # noqa: E501

        :param middle_name: The middle_name of this CandidateWithId.  # noqa: E501
        :type: str
        """

        self._middle_name = middle_name

    @property
    def last_name(self):
        """Gets the last_name of this CandidateWithId.  # noqa: E501

        Last Name/ Surname of the candidate.  # noqa: E501

        :return: The last_name of this CandidateWithId.  # noqa: E501
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """Sets the last_name of this CandidateWithId.

        Last Name/ Surname of the candidate.  # noqa: E501

        :param last_name: The last_name of this CandidateWithId.  # noqa: E501
        :type: str
        """
        if last_name is None:
            raise ValueError("Invalid value for `last_name`, must not be `None`")  # noqa: E501

        self._last_name = last_name

    @property
    def contact_data(self):
        """Gets the contact_data of this CandidateWithId.  # noqa: E501


        :return: The contact_data of this CandidateWithId.  # noqa: E501
        :rtype: ContactData
        """
        return self._contact_data

    @contact_data.setter
    def contact_data(self, contact_data):
        """Sets the contact_data of this CandidateWithId.


        :param contact_data: The contact_data of this CandidateWithId.  # noqa: E501
        :type: ContactData
        """

        self._contact_data = contact_data

    @property
    def address_data(self):
        """Gets the address_data of this CandidateWithId.  # noqa: E501


        :return: The address_data of this CandidateWithId.  # noqa: E501
        :rtype: AddressData
        """
        return self._address_data

    @address_data.setter
    def address_data(self, address_data):
        """Sets the address_data of this CandidateWithId.


        :param address_data: The address_data of this CandidateWithId.  # noqa: E501
        :type: AddressData
        """

        self._address_data = address_data

    @property
    def sms_opt_in(self):
        """Gets the sms_opt_in of this CandidateWithId.  # noqa: E501

        Opt in for SMS Campaigns.  # noqa: E501

        :return: The sms_opt_in of this CandidateWithId.  # noqa: E501
        :rtype: bool
        """
        return self._sms_opt_in

    @sms_opt_in.setter
    def sms_opt_in(self, sms_opt_in):
        """Sets the sms_opt_in of this CandidateWithId.

        Opt in for SMS Campaigns.  # noqa: E501

        :param sms_opt_in: The sms_opt_in of this CandidateWithId.  # noqa: E501
        :type: bool
        """

        self._sms_opt_in = sms_opt_in

    @property
    def experience_data(self):
        """Gets the experience_data of this CandidateWithId.  # noqa: E501


        :return: The experience_data of this CandidateWithId.  # noqa: E501
        :rtype: list[ExperienceData]
        """
        return self._experience_data

    @experience_data.setter
    def experience_data(self, experience_data):
        """Sets the experience_data of this CandidateWithId.


        :param experience_data: The experience_data of this CandidateWithId.  # noqa: E501
        :type: list[ExperienceData]
        """

        self._experience_data = experience_data

    @property
    def education_data(self):
        """Gets the education_data of this CandidateWithId.  # noqa: E501


        :return: The education_data of this CandidateWithId.  # noqa: E501
        :rtype: list[EducationData]
        """
        return self._education_data

    @education_data.setter
    def education_data(self, education_data):
        """Sets the education_data of this CandidateWithId.


        :param education_data: The education_data of this CandidateWithId.  # noqa: E501
        :type: list[EducationData]
        """

        self._education_data = education_data

    @property
    def id(self):
        """Gets the id of this CandidateWithId.  # noqa: E501

        It is a 24-digit hexadecimal value that represents Applicant Id.  # noqa: E501

        :return: The id of this CandidateWithId.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this CandidateWithId.

        It is a 24-digit hexadecimal value that represents Applicant Id.  # noqa: E501

        :param id: The id of this CandidateWithId.  # noqa: E501
        :type: str
        """

        self._id = id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CandidateWithId, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CandidateWithId):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa

"""
    job-parser-api

    The process of extracting important information from the raw job description is called Job Parsing. This information can include things like job titles, required skills, required experience, job duties, and qualifications.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

from __future__ import absolute_import

# import apis into sdk package
from phenom.api.jobparser.job_parsing_api import JobParsingApi
# import ApiClient
from phenom.commons.api_client import ApiClient
from phenom.commons.configuration import Configuration
# import models into sdk package
from phenom.api.jobparser.models.error_response import ErrorResponse
from phenom.api.jobparser.models.error_response_response import ErrorResponseResponse
from phenom.api.jobparser.models.jd_request import JDRequest
from phenom.api.jobparser.models.job_response import JobResponse
from phenom.api.jobparser.models.job_response_job_experience import JobResponseJobExperience
from phenom.api.jobparser.models.job_response_job_type_fields import JobResponseJobTypeFields
from phenom.api.jobparser.models.job_response_onet import JobResponseOnet
from phenom.api.jobparser.models.job_response_skill_ranking import JobResponseSkillRanking



# coding: utf-8

"""
    job-parser-api

    The process of extracting important information from the raw job description is called Job Parsing. This information can include things like job titles, required skills, required experience, job duties, and qualifications.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class JobResponseJobExperience(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'min_overall_exp': 'int',
        'max_overall_exp': 'int'
    }

    attribute_map = {
        'min_overall_exp': 'minOverallExp',
        'max_overall_exp': 'maxOverallExp'
    }

    def __init__(self, min_overall_exp=None, max_overall_exp=None):  # noqa: E501
        """JobResponseJobExperience - a model defined in Swagger"""  # noqa: E501
        self._min_overall_exp = None
        self._max_overall_exp = None
        self.discriminator = None
        if min_overall_exp is not None:
            self.min_overall_exp = min_overall_exp
        if max_overall_exp is not None:
            self.max_overall_exp = max_overall_exp

    @property
    def min_overall_exp(self):
        """Gets the min_overall_exp of this JobResponseJobExperience.  # noqa: E501

        Minimum experience required.  # noqa: E501

        :return: The min_overall_exp of this JobResponseJobExperience.  # noqa: E501
        :rtype: int
        """
        return self._min_overall_exp

    @min_overall_exp.setter
    def min_overall_exp(self, min_overall_exp):
        """Sets the min_overall_exp of this JobResponseJobExperience.

        Minimum experience required.  # noqa: E501

        :param min_overall_exp: The min_overall_exp of this JobResponseJobExperience.  # noqa: E501
        :type: int
        """

        self._min_overall_exp = min_overall_exp

    @property
    def max_overall_exp(self):
        """Gets the max_overall_exp of this JobResponseJobExperience.  # noqa: E501

        Maximum experience required.  # noqa: E501

        :return: The max_overall_exp of this JobResponseJobExperience.  # noqa: E501
        :rtype: int
        """
        return self._max_overall_exp

    @max_overall_exp.setter
    def max_overall_exp(self, max_overall_exp):
        """Sets the max_overall_exp of this JobResponseJobExperience.

        Maximum experience required.  # noqa: E501

        :param max_overall_exp: The max_overall_exp of this JobResponseJobExperience.  # noqa: E501
        :type: int
        """

        self._max_overall_exp = max_overall_exp

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(JobResponseJobExperience, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, JobResponseJobExperience):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    projects-api

    These APIs allows you to create workflow statuses, which are then assigned to workflows. These workflows, containing multiple statuses, are subsequently linked to projects. Additionally, candidates are associated with projects, defining the path they are meant to follow within the established workflows.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class GetProjectsResponseHiringTeamList(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'email_id': 'str',
        'role': 'str',
        'id': 'str',
        'type': 'str',
        'picture_s3_url': 'str'
    }

    attribute_map = {
        'name': 'name',
        'email_id': 'emailId',
        'role': 'role',
        'id': 'id',
        'type': 'type',
        'picture_s3_url': 'pictureS3Url'
    }

    def __init__(self, name=None, email_id=None, role=None, id=None, type=None, picture_s3_url=None):  # noqa: E501
        """GetProjectsResponseHiringTeamList - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._email_id = None
        self._role = None
        self._id = None
        self._type = None
        self._picture_s3_url = None
        self.discriminator = None
        if name is not None:
            self.name = name
        if email_id is not None:
            self.email_id = email_id
        if role is not None:
            self.role = role
        if id is not None:
            self.id = id
        if type is not None:
            self.type = type
        if picture_s3_url is not None:
            self.picture_s3_url = picture_s3_url

    @property
    def name(self):
        """Gets the name of this GetProjectsResponseHiringTeamList.  # noqa: E501

        The name of a member in the hiring team.  # noqa: E501

        :return: The name of this GetProjectsResponseHiringTeamList.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this GetProjectsResponseHiringTeamList.

        The name of a member in the hiring team.  # noqa: E501

        :param name: The name of this GetProjectsResponseHiringTeamList.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def email_id(self):
        """Gets the email_id of this GetProjectsResponseHiringTeamList.  # noqa: E501

        The email address of a member in the hiring team.  # noqa: E501

        :return: The email_id of this GetProjectsResponseHiringTeamList.  # noqa: E501
        :rtype: str
        """
        return self._email_id

    @email_id.setter
    def email_id(self, email_id):
        """Sets the email_id of this GetProjectsResponseHiringTeamList.

        The email address of a member in the hiring team.  # noqa: E501

        :param email_id: The email_id of this GetProjectsResponseHiringTeamList.  # noqa: E501
        :type: str
        """

        self._email_id = email_id

    @property
    def role(self):
        """Gets the role of this GetProjectsResponseHiringTeamList.  # noqa: E501

        The role of a member in the hiring team.  # noqa: E501

        :return: The role of this GetProjectsResponseHiringTeamList.  # noqa: E501
        :rtype: str
        """
        return self._role

    @role.setter
    def role(self, role):
        """Sets the role of this GetProjectsResponseHiringTeamList.

        The role of a member in the hiring team.  # noqa: E501

        :param role: The role of this GetProjectsResponseHiringTeamList.  # noqa: E501
        :type: str
        """

        self._role = role

    @property
    def id(self):
        """Gets the id of this GetProjectsResponseHiringTeamList.  # noqa: E501

        The unique identifier for a member in the hiring team.  # noqa: E501

        :return: The id of this GetProjectsResponseHiringTeamList.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this GetProjectsResponseHiringTeamList.

        The unique identifier for a member in the hiring team.  # noqa: E501

        :param id: The id of this GetProjectsResponseHiringTeamList.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def type(self):
        """Gets the type of this GetProjectsResponseHiringTeamList.  # noqa: E501

        The type of a member in the hiring team.  # noqa: E501

        :return: The type of this GetProjectsResponseHiringTeamList.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this GetProjectsResponseHiringTeamList.

        The type of a member in the hiring team.  # noqa: E501

        :param type: The type of this GetProjectsResponseHiringTeamList.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def picture_s3_url(self):
        """Gets the picture_s3_url of this GetProjectsResponseHiringTeamList.  # noqa: E501

        The URL of the picture of a member in the hiring team.  # noqa: E501

        :return: The picture_s3_url of this GetProjectsResponseHiringTeamList.  # noqa: E501
        :rtype: str
        """
        return self._picture_s3_url

    @picture_s3_url.setter
    def picture_s3_url(self, picture_s3_url):
        """Sets the picture_s3_url of this GetProjectsResponseHiringTeamList.

        The URL of the picture of a member in the hiring team.  # noqa: E501

        :param picture_s3_url: The picture_s3_url of this GetProjectsResponseHiringTeamList.  # noqa: E501
        :type: str
        """

        self._picture_s3_url = picture_s3_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GetProjectsResponseHiringTeamList, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetProjectsResponseHiringTeamList):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    aisourcing-api

    AI matching FitScore provides a concise assessment indicating how well a candidate aligns with a job based on their skills, experience, and qualifications.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from phenom.commons.api_client import ApiClient


class AIMatchingApi(object):
    base_path = "/ai-matching"  # your base path

    def __init__(self, token, gateway_url, apikey, api_client=None):
        if api_client is None:
            api_client = ApiClient(gateway_url + self.base_path, apikey, token)
        self.api_client = api_client

    def job_fitscore(self, body, **kwargs):  # noqa: E501
        """Job Fitscore  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.job_fitscore(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param FitScoreRequest body: (required)
        :return: FitscoreResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.job_fitscore_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.job_fitscore_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def job_fitscore_with_http_info(self, body, **kwargs):  # noqa: E501
        """Job Fitscore  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.job_fitscore_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param FitScoreRequest body: (required)
        :return: FitscoreResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method job_fitscore" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `job_fitscore`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/candidates/job-fitscore', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='FitscoreResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def skills_matching(self, x_ph_user_id, candidate_id, job_id, **kwargs):  # noqa: E501
        """Skills Matching  # noqa: E501

        This API provides details of matching skills between a job and candidate.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.skills_matching(x_ph_user_id, candidate_id, job_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_ph_user_id: Phenom Recruiter ID. (required)
        :param str candidate_id: Candidate ID given by Phenom's CRM. (required)
        :param str job_id: ATS Job ID. (required)
        :return: SkillMatchingResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.skills_matching_with_http_info(x_ph_user_id, candidate_id, job_id, **kwargs)  # noqa: E501
        else:
            (data) = self.skills_matching_with_http_info(x_ph_user_id, candidate_id, job_id, **kwargs)  # noqa: E501
            return data

    def skills_matching_with_http_info(self, x_ph_user_id, candidate_id, job_id, **kwargs):  # noqa: E501
        """Skills Matching  # noqa: E501

        This API provides details of matching skills between a job and candidate.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.skills_matching_with_http_info(x_ph_user_id, candidate_id, job_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str x_ph_user_id: Phenom Recruiter ID. (required)
        :param str candidate_id: Candidate ID given by Phenom's CRM. (required)
        :param str job_id: ATS Job ID. (required)
        :return: SkillMatchingResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['x_ph_user_id', 'candidate_id', 'job_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method skills_matching" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'x_ph_user_id' is set
        if ('x_ph_user_id' not in params or
                params['x_ph_user_id'] is None):
            raise ValueError("Missing the required parameter `x_ph_user_id` when calling `skills_matching`")  # noqa: E501
        # verify the required parameter 'candidate_id' is set
        if ('candidate_id' not in params or
                params['candidate_id'] is None):
            raise ValueError("Missing the required parameter `candidate_id` when calling `skills_matching`")  # noqa: E501
        # verify the required parameter 'job_id' is set
        if ('job_id' not in params or
                params['job_id'] is None):
            raise ValueError("Missing the required parameter `job_id` when calling `skills_matching`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'candidate_id' in params:
            path_params['candidateId'] = params['candidate_id']  # noqa: E501
        if 'job_id' in params:
            path_params['jobId'] = params['job_id']  # noqa: E501

        query_params = []

        header_params = {}
        if 'x_ph_user_id' in params:
            header_params['x-ph-userId'] = params['x_ph_user_id']  # noqa: E501

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/candidates/{candidateId}/jobs/{jobId}/matching-skills', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SkillMatchingResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    videoplatform-api

    Interview Screening APIs allows to invite candidate to interview, evaluate and review candidates interview performances.  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@phenompeople.com
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class GetInterviewDetailsResponseData(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'video_screen_id': 'str',
        'number_of_questions': 'float',
        'status': 'str',
        'candidate_info': 'GetInterviewDetailsResponseDataCandidateInfo',
        'questions': 'list[GetInterviewDetailsResponseDataQuestions]',
        'interview_details': 'GetInterviewDetailsResponseDataInterviewDetails',
        'site_type': 'str',
        'locale': 'str',
        'date_created': 'int',
        'last_updated': 'int',
        'recruiter_details': 'GetInterviewDetailsResponseDataRecruiterDetails',
        'invitation_code': 'str',
        'validity_end_date_time_stamp': 'float',
        'interview_valid_for_in_days': 'float',
        'active': 'bool',
        'interview_overall_avg_rating': 'float',
        'timezone': 'str',
        'interview_url': 'str',
        'lc_candidate_name': 'str',
        'questionnaire_id': 'str',
        'assessment_score': 'float',
        'answered_score_points': 'float',
        'max_score_points': 'float',
        'attachment_status': 'bool'
    }

    attribute_map = {
        'video_screen_id': 'videoScreenId',
        'number_of_questions': 'numberOfQuestions',
        'status': 'status',
        'candidate_info': 'candidateInfo',
        'questions': 'questions',
        'interview_details': 'interviewDetails',
        'site_type': 'siteType',
        'locale': 'locale',
        'date_created': 'dateCreated',
        'last_updated': 'lastUpdated',
        'recruiter_details': 'recruiterDetails',
        'invitation_code': 'invitationCode',
        'validity_end_date_time_stamp': 'validityEndDateTimeStamp',
        'interview_valid_for_in_days': 'interviewValidForInDays',
        'active': 'active',
        'interview_overall_avg_rating': 'interviewOverallAvgRating',
        'timezone': 'timezone',
        'interview_url': 'interviewURL',
        'lc_candidate_name': 'lcCandidateName',
        'questionnaire_id': 'questionnaireId',
        'assessment_score': 'assessmentScore',
        'answered_score_points': 'answeredScorePoints',
        'max_score_points': 'maxScorePoints',
        'attachment_status': 'attachmentStatus'
    }

    def __init__(self, video_screen_id=None, number_of_questions=None, status=None, candidate_info=None, questions=None, interview_details=None, site_type=None, locale=None, date_created=None, last_updated=None, recruiter_details=None, invitation_code=None, validity_end_date_time_stamp=None, interview_valid_for_in_days=None, active=None, interview_overall_avg_rating=None, timezone=None, interview_url=None, lc_candidate_name=None, questionnaire_id=None, assessment_score=None, answered_score_points=None, max_score_points=None, attachment_status=None):  # noqa: E501
        """GetInterviewDetailsResponseData - a model defined in Swagger"""  # noqa: E501
        self._video_screen_id = None
        self._number_of_questions = None
        self._status = None
        self._candidate_info = None
        self._questions = None
        self._interview_details = None
        self._site_type = None
        self._locale = None
        self._date_created = None
        self._last_updated = None
        self._recruiter_details = None
        self._invitation_code = None
        self._validity_end_date_time_stamp = None
        self._interview_valid_for_in_days = None
        self._active = None
        self._interview_overall_avg_rating = None
        self._timezone = None
        self._interview_url = None
        self._lc_candidate_name = None
        self._questionnaire_id = None
        self._assessment_score = None
        self._answered_score_points = None
        self._max_score_points = None
        self._attachment_status = None
        self.discriminator = None
        self.video_screen_id = video_screen_id
        if number_of_questions is not None:
            self.number_of_questions = number_of_questions
        self.status = status
        self.candidate_info = candidate_info
        self.questions = questions
        self.interview_details = interview_details
        self.site_type = site_type
        self.locale = locale
        self.date_created = date_created
        self.last_updated = last_updated
        self.recruiter_details = recruiter_details
        self.invitation_code = invitation_code
        self.validity_end_date_time_stamp = validity_end_date_time_stamp
        self.interview_valid_for_in_days = interview_valid_for_in_days
        self.active = active
        self.interview_overall_avg_rating = interview_overall_avg_rating
        if timezone is not None:
            self.timezone = timezone
        self.interview_url = interview_url
        self.lc_candidate_name = lc_candidate_name
        self.questionnaire_id = questionnaire_id
        self.assessment_score = assessment_score
        self.answered_score_points = answered_score_points
        self.max_score_points = max_score_points
        self.attachment_status = attachment_status

    @property
    def video_screen_id(self):
        """Gets the video_screen_id of this GetInterviewDetailsResponseData.  # noqa: E501

        This is the interview id.  # noqa: E501

        :return: The video_screen_id of this GetInterviewDetailsResponseData.  # noqa: E501
        :rtype: str
        """
        return self._video_screen_id

    @video_screen_id.setter
    def video_screen_id(self, video_screen_id):
        """Sets the video_screen_id of this GetInterviewDetailsResponseData.

        This is the interview id.  # noqa: E501

        :param video_screen_id: The video_screen_id of this GetInterviewDetailsResponseData.  # noqa: E501
        :type: str
        """
        if video_screen_id is None:
            raise ValueError("Invalid value for `video_screen_id`, must not be `None`")  # noqa: E501

        self._video_screen_id = video_screen_id

    @property
    def number_of_questions(self):
        """Gets the number_of_questions of this GetInterviewDetailsResponseData.  # noqa: E501

        Number of questions in one way interview.  # noqa: E501

        :return: The number_of_questions of this GetInterviewDetailsResponseData.  # noqa: E501
        :rtype: float
        """
        return self._number_of_questions

    @number_of_questions.setter
    def number_of_questions(self, number_of_questions):
        """Sets the number_of_questions of this GetInterviewDetailsResponseData.

        Number of questions in one way interview.  # noqa: E501

        :param number_of_questions: The number_of_questions of this GetInterviewDetailsResponseData.  # noqa: E501
        :type: float
        """

        self._number_of_questions = number_of_questions

    @property
    def status(self):
        """Gets the status of this GetInterviewDetailsResponseData.  # noqa: E501

        Current status of one way interview.  # noqa: E501

        :return: The status of this GetInterviewDetailsResponseData.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this GetInterviewDetailsResponseData.

        Current status of one way interview.  # noqa: E501

        :param status: The status of this GetInterviewDetailsResponseData.  # noqa: E501
        :type: str
        """
        if status is None:
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501

        self._status = status

    @property
    def candidate_info(self):
        """Gets the candidate_info of this GetInterviewDetailsResponseData.  # noqa: E501


        :return: The candidate_info of this GetInterviewDetailsResponseData.  # noqa: E501
        :rtype: GetInterviewDetailsResponseDataCandidateInfo
        """
        return self._candidate_info

    @candidate_info.setter
    def candidate_info(self, candidate_info):
        """Sets the candidate_info of this GetInterviewDetailsResponseData.


        :param candidate_info: The candidate_info of this GetInterviewDetailsResponseData.  # noqa: E501
        :type: GetInterviewDetailsResponseDataCandidateInfo
        """
        if candidate_info is None:
            raise ValueError("Invalid value for `candidate_info`, must not be `None`")  # noqa: E501

        self._candidate_info = candidate_info

    @property
    def questions(self):
        """Gets the questions of this GetInterviewDetailsResponseData.  # noqa: E501

        Contains all questions for this interview.  # noqa: E501

        :return: The questions of this GetInterviewDetailsResponseData.  # noqa: E501
        :rtype: list[GetInterviewDetailsResponseDataQuestions]
        """
        return self._questions

    @questions.setter
    def questions(self, questions):
        """Sets the questions of this GetInterviewDetailsResponseData.

        Contains all questions for this interview.  # noqa: E501

        :param questions: The questions of this GetInterviewDetailsResponseData.  # noqa: E501
        :type: list[GetInterviewDetailsResponseDataQuestions]
        """
        if questions is None:
            raise ValueError("Invalid value for `questions`, must not be `None`")  # noqa: E501

        self._questions = questions

    @property
    def interview_details(self):
        """Gets the interview_details of this GetInterviewDetailsResponseData.  # noqa: E501


        :return: The interview_details of this GetInterviewDetailsResponseData.  # noqa: E501
        :rtype: GetInterviewDetailsResponseDataInterviewDetails
        """
        return self._interview_details

    @interview_details.setter
    def interview_details(self, interview_details):
        """Sets the interview_details of this GetInterviewDetailsResponseData.


        :param interview_details: The interview_details of this GetInterviewDetailsResponseData.  # noqa: E501
        :type: GetInterviewDetailsResponseDataInterviewDetails
        """
        if interview_details is None:
            raise ValueError("Invalid value for `interview_details`, must not be `None`")  # noqa: E501

        self._interview_details = interview_details

    @property
    def site_type(self):
        """Gets the site_type of this GetInterviewDetailsResponseData.  # noqa: E501

        This indicates whether job posted variant. If there are multi branding sites example: Parent Company, Child Company.  # noqa: E501

        :return: The site_type of this GetInterviewDetailsResponseData.  # noqa: E501
        :rtype: str
        """
        return self._site_type

    @site_type.setter
    def site_type(self, site_type):
        """Sets the site_type of this GetInterviewDetailsResponseData.

        This indicates whether job posted variant. If there are multi branding sites example: Parent Company, Child Company.  # noqa: E501

        :param site_type: The site_type of this GetInterviewDetailsResponseData.  # noqa: E501
        :type: str
        """
        if site_type is None:
            raise ValueError("Invalid value for `site_type`, must not be `None`")  # noqa: E501

        self._site_type = site_type

    @property
    def locale(self):
        """Gets the locale of this GetInterviewDetailsResponseData.  # noqa: E501

        Job locale.  # noqa: E501

        :return: The locale of this GetInterviewDetailsResponseData.  # noqa: E501
        :rtype: str
        """
        return self._locale

    @locale.setter
    def locale(self, locale):
        """Sets the locale of this GetInterviewDetailsResponseData.

        Job locale.  # noqa: E501

        :param locale: The locale of this GetInterviewDetailsResponseData.  # noqa: E501
        :type: str
        """
        if locale is None:
            raise ValueError("Invalid value for `locale`, must not be `None`")  # noqa: E501

        self._locale = locale

    @property
    def date_created(self):
        """Gets the date_created of this GetInterviewDetailsResponseData.  # noqa: E501

        Date when interview is invited.  # noqa: E501

        :return: The date_created of this GetInterviewDetailsResponseData.  # noqa: E501
        :rtype: int
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """Sets the date_created of this GetInterviewDetailsResponseData.

        Date when interview is invited.  # noqa: E501

        :param date_created: The date_created of this GetInterviewDetailsResponseData.  # noqa: E501
        :type: int
        """
        if date_created is None:
            raise ValueError("Invalid value for `date_created`, must not be `None`")  # noqa: E501

        self._date_created = date_created

    @property
    def last_updated(self):
        """Gets the last_updated of this GetInterviewDetailsResponseData.  # noqa: E501

        Date when last status is updated.  # noqa: E501

        :return: The last_updated of this GetInterviewDetailsResponseData.  # noqa: E501
        :rtype: int
        """
        return self._last_updated

    @last_updated.setter
    def last_updated(self, last_updated):
        """Sets the last_updated of this GetInterviewDetailsResponseData.

        Date when last status is updated.  # noqa: E501

        :param last_updated: The last_updated of this GetInterviewDetailsResponseData.  # noqa: E501
        :type: int
        """
        if last_updated is None:
            raise ValueError("Invalid value for `last_updated`, must not be `None`")  # noqa: E501

        self._last_updated = last_updated

    @property
    def recruiter_details(self):
        """Gets the recruiter_details of this GetInterviewDetailsResponseData.  # noqa: E501


        :return: The recruiter_details of this GetInterviewDetailsResponseData.  # noqa: E501
        :rtype: GetInterviewDetailsResponseDataRecruiterDetails
        """
        return self._recruiter_details

    @recruiter_details.setter
    def recruiter_details(self, recruiter_details):
        """Sets the recruiter_details of this GetInterviewDetailsResponseData.


        :param recruiter_details: The recruiter_details of this GetInterviewDetailsResponseData.  # noqa: E501
        :type: GetInterviewDetailsResponseDataRecruiterDetails
        """
        if recruiter_details is None:
            raise ValueError("Invalid value for `recruiter_details`, must not be `None`")  # noqa: E501

        self._recruiter_details = recruiter_details

    @property
    def invitation_code(self):
        """Gets the invitation_code of this GetInterviewDetailsResponseData.  # noqa: E501

        This is the invitation code of the invited interview.  # noqa: E501

        :return: The invitation_code of this GetInterviewDetailsResponseData.  # noqa: E501
        :rtype: str
        """
        return self._invitation_code

    @invitation_code.setter
    def invitation_code(self, invitation_code):
        """Sets the invitation_code of this GetInterviewDetailsResponseData.

        This is the invitation code of the invited interview.  # noqa: E501

        :param invitation_code: The invitation_code of this GetInterviewDetailsResponseData.  # noqa: E501
        :type: str
        """
        if invitation_code is None:
            raise ValueError("Invalid value for `invitation_code`, must not be `None`")  # noqa: E501

        self._invitation_code = invitation_code

    @property
    def validity_end_date_time_stamp(self):
        """Gets the validity_end_date_time_stamp of this GetInterviewDetailsResponseData.  # noqa: E501

        This is the interview expiry timestamp.  # noqa: E501

        :return: The validity_end_date_time_stamp of this GetInterviewDetailsResponseData.  # noqa: E501
        :rtype: float
        """
        return self._validity_end_date_time_stamp

    @validity_end_date_time_stamp.setter
    def validity_end_date_time_stamp(self, validity_end_date_time_stamp):
        """Sets the validity_end_date_time_stamp of this GetInterviewDetailsResponseData.

        This is the interview expiry timestamp.  # noqa: E501

        :param validity_end_date_time_stamp: The validity_end_date_time_stamp of this GetInterviewDetailsResponseData.  # noqa: E501
        :type: float
        """
        if validity_end_date_time_stamp is None:
            raise ValueError("Invalid value for `validity_end_date_time_stamp`, must not be `None`")  # noqa: E501

        self._validity_end_date_time_stamp = validity_end_date_time_stamp

    @property
    def interview_valid_for_in_days(self):
        """Gets the interview_valid_for_in_days of this GetInterviewDetailsResponseData.  # noqa: E501

        This is the days validity of interview.  # noqa: E501

        :return: The interview_valid_for_in_days of this GetInterviewDetailsResponseData.  # noqa: E501
        :rtype: float
        """
        return self._interview_valid_for_in_days

    @interview_valid_for_in_days.setter
    def interview_valid_for_in_days(self, interview_valid_for_in_days):
        """Sets the interview_valid_for_in_days of this GetInterviewDetailsResponseData.

        This is the days validity of interview.  # noqa: E501

        :param interview_valid_for_in_days: The interview_valid_for_in_days of this GetInterviewDetailsResponseData.  # noqa: E501
        :type: float
        """
        if interview_valid_for_in_days is None:
            raise ValueError("Invalid value for `interview_valid_for_in_days`, must not be `None`")  # noqa: E501

        self._interview_valid_for_in_days = interview_valid_for_in_days

    @property
    def active(self):
        """Gets the active of this GetInterviewDetailsResponseData.  # noqa: E501

        This indicates whether interview is still active. True if active else false.  # noqa: E501

        :return: The active of this GetInterviewDetailsResponseData.  # noqa: E501
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """Sets the active of this GetInterviewDetailsResponseData.

        This indicates whether interview is still active. True if active else false.  # noqa: E501

        :param active: The active of this GetInterviewDetailsResponseData.  # noqa: E501
        :type: bool
        """
        if active is None:
            raise ValueError("Invalid value for `active`, must not be `None`")  # noqa: E501

        self._active = active

    @property
    def interview_overall_avg_rating(self):
        """Gets the interview_overall_avg_rating of this GetInterviewDetailsResponseData.  # noqa: E501

        This indicates the overall average rating of the interview.  # noqa: E501

        :return: The interview_overall_avg_rating of this GetInterviewDetailsResponseData.  # noqa: E501
        :rtype: float
        """
        return self._interview_overall_avg_rating

    @interview_overall_avg_rating.setter
    def interview_overall_avg_rating(self, interview_overall_avg_rating):
        """Sets the interview_overall_avg_rating of this GetInterviewDetailsResponseData.

        This indicates the overall average rating of the interview.  # noqa: E501

        :param interview_overall_avg_rating: The interview_overall_avg_rating of this GetInterviewDetailsResponseData.  # noqa: E501
        :type: float
        """
        if interview_overall_avg_rating is None:
            raise ValueError("Invalid value for `interview_overall_avg_rating`, must not be `None`")  # noqa: E501

        self._interview_overall_avg_rating = interview_overall_avg_rating

    @property
    def timezone(self):
        """Gets the timezone of this GetInterviewDetailsResponseData.  # noqa: E501

        This is the timezone of the invited interview.  # noqa: E501

        :return: The timezone of this GetInterviewDetailsResponseData.  # noqa: E501
        :rtype: str
        """
        return self._timezone

    @timezone.setter
    def timezone(self, timezone):
        """Sets the timezone of this GetInterviewDetailsResponseData.

        This is the timezone of the invited interview.  # noqa: E501

        :param timezone: The timezone of this GetInterviewDetailsResponseData.  # noqa: E501
        :type: str
        """

        self._timezone = timezone

    @property
    def interview_url(self):
        """Gets the interview_url of this GetInterviewDetailsResponseData.  # noqa: E501

        This is the interview url.  # noqa: E501

        :return: The interview_url of this GetInterviewDetailsResponseData.  # noqa: E501
        :rtype: str
        """
        return self._interview_url

    @interview_url.setter
    def interview_url(self, interview_url):
        """Sets the interview_url of this GetInterviewDetailsResponseData.

        This is the interview url.  # noqa: E501

        :param interview_url: The interview_url of this GetInterviewDetailsResponseData.  # noqa: E501
        :type: str
        """
        if interview_url is None:
            raise ValueError("Invalid value for `interview_url`, must not be `None`")  # noqa: E501

        self._interview_url = interview_url

    @property
    def lc_candidate_name(self):
        """Gets the lc_candidate_name of this GetInterviewDetailsResponseData.  # noqa: E501

        This is the candidate name.  # noqa: E501

        :return: The lc_candidate_name of this GetInterviewDetailsResponseData.  # noqa: E501
        :rtype: str
        """
        return self._lc_candidate_name

    @lc_candidate_name.setter
    def lc_candidate_name(self, lc_candidate_name):
        """Sets the lc_candidate_name of this GetInterviewDetailsResponseData.

        This is the candidate name.  # noqa: E501

        :param lc_candidate_name: The lc_candidate_name of this GetInterviewDetailsResponseData.  # noqa: E501
        :type: str
        """
        if lc_candidate_name is None:
            raise ValueError("Invalid value for `lc_candidate_name`, must not be `None`")  # noqa: E501

        self._lc_candidate_name = lc_candidate_name

    @property
    def questionnaire_id(self):
        """Gets the questionnaire_id of this GetInterviewDetailsResponseData.  # noqa: E501

        This is the questionnaire used for the invitation.  # noqa: E501

        :return: The questionnaire_id of this GetInterviewDetailsResponseData.  # noqa: E501
        :rtype: str
        """
        return self._questionnaire_id

    @questionnaire_id.setter
    def questionnaire_id(self, questionnaire_id):
        """Sets the questionnaire_id of this GetInterviewDetailsResponseData.

        This is the questionnaire used for the invitation.  # noqa: E501

        :param questionnaire_id: The questionnaire_id of this GetInterviewDetailsResponseData.  # noqa: E501
        :type: str
        """
        if questionnaire_id is None:
            raise ValueError("Invalid value for `questionnaire_id`, must not be `None`")  # noqa: E501

        self._questionnaire_id = questionnaire_id

    @property
    def assessment_score(self):
        """Gets the assessment_score of this GetInterviewDetailsResponseData.  # noqa: E501

        This is the score if there any scored questions.  # noqa: E501

        :return: The assessment_score of this GetInterviewDetailsResponseData.  # noqa: E501
        :rtype: float
        """
        return self._assessment_score

    @assessment_score.setter
    def assessment_score(self, assessment_score):
        """Sets the assessment_score of this GetInterviewDetailsResponseData.

        This is the score if there any scored questions.  # noqa: E501

        :param assessment_score: The assessment_score of this GetInterviewDetailsResponseData.  # noqa: E501
        :type: float
        """
        if assessment_score is None:
            raise ValueError("Invalid value for `assessment_score`, must not be `None`")  # noqa: E501

        self._assessment_score = assessment_score

    @property
    def answered_score_points(self):
        """Gets the answered_score_points of this GetInterviewDetailsResponseData.  # noqa: E501

        Answered score points for the selected question options.  # noqa: E501

        :return: The answered_score_points of this GetInterviewDetailsResponseData.  # noqa: E501
        :rtype: float
        """
        return self._answered_score_points

    @answered_score_points.setter
    def answered_score_points(self, answered_score_points):
        """Sets the answered_score_points of this GetInterviewDetailsResponseData.

        Answered score points for the selected question options.  # noqa: E501

        :param answered_score_points: The answered_score_points of this GetInterviewDetailsResponseData.  # noqa: E501
        :type: float
        """
        if answered_score_points is None:
            raise ValueError("Invalid value for `answered_score_points`, must not be `None`")  # noqa: E501

        self._answered_score_points = answered_score_points

    @property
    def max_score_points(self):
        """Gets the max_score_points of this GetInterviewDetailsResponseData.  # noqa: E501

        Max total points.  # noqa: E501

        :return: The max_score_points of this GetInterviewDetailsResponseData.  # noqa: E501
        :rtype: float
        """
        return self._max_score_points

    @max_score_points.setter
    def max_score_points(self, max_score_points):
        """Sets the max_score_points of this GetInterviewDetailsResponseData.

        Max total points.  # noqa: E501

        :param max_score_points: The max_score_points of this GetInterviewDetailsResponseData.  # noqa: E501
        :type: float
        """
        if max_score_points is None:
            raise ValueError("Invalid value for `max_score_points`, must not be `None`")  # noqa: E501

        self._max_score_points = max_score_points

    @property
    def attachment_status(self):
        """Gets the attachment_status of this GetInterviewDetailsResponseData.  # noqa: E501

        True if there is attachment for this question, False otherwise.  # noqa: E501

        :return: The attachment_status of this GetInterviewDetailsResponseData.  # noqa: E501
        :rtype: bool
        """
        return self._attachment_status

    @attachment_status.setter
    def attachment_status(self, attachment_status):
        """Sets the attachment_status of this GetInterviewDetailsResponseData.

        True if there is attachment for this question, False otherwise.  # noqa: E501

        :param attachment_status: The attachment_status of this GetInterviewDetailsResponseData.  # noqa: E501
        :type: bool
        """
        if attachment_status is None:
            raise ValueError("Invalid value for `attachment_status`, must not be `None`")  # noqa: E501

        self._attachment_status = attachment_status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GetInterviewDetailsResponseData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetInterviewDetailsResponseData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    hrm-api

    Hiring Manager can view all the pending tasks and evaluate the interview if any pending interviews.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class GetCandidatesResponseDataOnDemandInterviewScreening(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'vis_priority': 'str',
        'interview_overall_avg_rating': 'float',
        'created_date': 'str',
        'updated_date': 'str',
        'validity_end_date_time_stamp': 'str',
        'current_status': 'str',
        'recruiter_user_id': 'str',
        'questionnaire_id': 'str',
        'video_screen_interview_id': 'str',
        'video_screen_id': 'str',
        'interview_title': 'str',
        'thumbnail_url': 'str'
    }

    attribute_map = {
        'vis_priority': 'visPriority',
        'interview_overall_avg_rating': 'interviewOverallAvgRating',
        'created_date': 'createdDate',
        'updated_date': 'updatedDate',
        'validity_end_date_time_stamp': 'validityEndDateTimeStamp',
        'current_status': 'currentStatus',
        'recruiter_user_id': 'recruiterUserId',
        'questionnaire_id': 'questionnaireId',
        'video_screen_interview_id': 'videoScreenInterviewId',
        'video_screen_id': 'videoScreenId',
        'interview_title': 'interviewTitle',
        'thumbnail_url': 'thumbnailUrl'
    }

    def __init__(self, vis_priority=None, interview_overall_avg_rating=None, created_date=None, updated_date=None, validity_end_date_time_stamp=None, current_status=None, recruiter_user_id=None, questionnaire_id=None, video_screen_interview_id=None, video_screen_id=None, interview_title=None, thumbnail_url=None):  # noqa: E501
        """GetCandidatesResponseDataOnDemandInterviewScreening - a model defined in Swagger"""  # noqa: E501
        self._vis_priority = None
        self._interview_overall_avg_rating = None
        self._created_date = None
        self._updated_date = None
        self._validity_end_date_time_stamp = None
        self._current_status = None
        self._recruiter_user_id = None
        self._questionnaire_id = None
        self._video_screen_interview_id = None
        self._video_screen_id = None
        self._interview_title = None
        self._thumbnail_url = None
        self.discriminator = None
        if vis_priority is not None:
            self.vis_priority = vis_priority
        if interview_overall_avg_rating is not None:
            self.interview_overall_avg_rating = interview_overall_avg_rating
        if created_date is not None:
            self.created_date = created_date
        if updated_date is not None:
            self.updated_date = updated_date
        if validity_end_date_time_stamp is not None:
            self.validity_end_date_time_stamp = validity_end_date_time_stamp
        if current_status is not None:
            self.current_status = current_status
        if recruiter_user_id is not None:
            self.recruiter_user_id = recruiter_user_id
        if questionnaire_id is not None:
            self.questionnaire_id = questionnaire_id
        if video_screen_interview_id is not None:
            self.video_screen_interview_id = video_screen_interview_id
        if video_screen_id is not None:
            self.video_screen_id = video_screen_id
        if interview_title is not None:
            self.interview_title = interview_title
        if thumbnail_url is not None:
            self.thumbnail_url = thumbnail_url

    @property
    def vis_priority(self):
        """Gets the vis_priority of this GetCandidatesResponseDataOnDemandInterviewScreening.  # noqa: E501

        Vis priorities.   # noqa: E501

        :return: The vis_priority of this GetCandidatesResponseDataOnDemandInterviewScreening.  # noqa: E501
        :rtype: str
        """
        return self._vis_priority

    @vis_priority.setter
    def vis_priority(self, vis_priority):
        """Sets the vis_priority of this GetCandidatesResponseDataOnDemandInterviewScreening.

        Vis priorities.   # noqa: E501

        :param vis_priority: The vis_priority of this GetCandidatesResponseDataOnDemandInterviewScreening.  # noqa: E501
        :type: str
        """

        self._vis_priority = vis_priority

    @property
    def interview_overall_avg_rating(self):
        """Gets the interview_overall_avg_rating of this GetCandidatesResponseDataOnDemandInterviewScreening.  # noqa: E501

        Overall rating of the candidate in this job.  # noqa: E501

        :return: The interview_overall_avg_rating of this GetCandidatesResponseDataOnDemandInterviewScreening.  # noqa: E501
        :rtype: float
        """
        return self._interview_overall_avg_rating

    @interview_overall_avg_rating.setter
    def interview_overall_avg_rating(self, interview_overall_avg_rating):
        """Sets the interview_overall_avg_rating of this GetCandidatesResponseDataOnDemandInterviewScreening.

        Overall rating of the candidate in this job.  # noqa: E501

        :param interview_overall_avg_rating: The interview_overall_avg_rating of this GetCandidatesResponseDataOnDemandInterviewScreening.  # noqa: E501
        :type: float
        """

        self._interview_overall_avg_rating = interview_overall_avg_rating

    @property
    def created_date(self):
        """Gets the created_date of this GetCandidatesResponseDataOnDemandInterviewScreening.  # noqa: E501

        Creation date of the evaluation.  # noqa: E501

        :return: The created_date of this GetCandidatesResponseDataOnDemandInterviewScreening.  # noqa: E501
        :rtype: str
        """
        return self._created_date

    @created_date.setter
    def created_date(self, created_date):
        """Sets the created_date of this GetCandidatesResponseDataOnDemandInterviewScreening.

        Creation date of the evaluation.  # noqa: E501

        :param created_date: The created_date of this GetCandidatesResponseDataOnDemandInterviewScreening.  # noqa: E501
        :type: str
        """

        self._created_date = created_date

    @property
    def updated_date(self):
        """Gets the updated_date of this GetCandidatesResponseDataOnDemandInterviewScreening.  # noqa: E501

        Latest updated date of the evaluation.  # noqa: E501

        :return: The updated_date of this GetCandidatesResponseDataOnDemandInterviewScreening.  # noqa: E501
        :rtype: str
        """
        return self._updated_date

    @updated_date.setter
    def updated_date(self, updated_date):
        """Sets the updated_date of this GetCandidatesResponseDataOnDemandInterviewScreening.

        Latest updated date of the evaluation.  # noqa: E501

        :param updated_date: The updated_date of this GetCandidatesResponseDataOnDemandInterviewScreening.  # noqa: E501
        :type: str
        """

        self._updated_date = updated_date

    @property
    def validity_end_date_time_stamp(self):
        """Gets the validity_end_date_time_stamp of this GetCandidatesResponseDataOnDemandInterviewScreening.  # noqa: E501

        Validity end date of the evaluation.  # noqa: E501

        :return: The validity_end_date_time_stamp of this GetCandidatesResponseDataOnDemandInterviewScreening.  # noqa: E501
        :rtype: str
        """
        return self._validity_end_date_time_stamp

    @validity_end_date_time_stamp.setter
    def validity_end_date_time_stamp(self, validity_end_date_time_stamp):
        """Sets the validity_end_date_time_stamp of this GetCandidatesResponseDataOnDemandInterviewScreening.

        Validity end date of the evaluation.  # noqa: E501

        :param validity_end_date_time_stamp: The validity_end_date_time_stamp of this GetCandidatesResponseDataOnDemandInterviewScreening.  # noqa: E501
        :type: str
        """

        self._validity_end_date_time_stamp = validity_end_date_time_stamp

    @property
    def current_status(self):
        """Gets the current_status of this GetCandidatesResponseDataOnDemandInterviewScreening.  # noqa: E501

        Current status of the candidate with respect to this job and this evaluation.  # noqa: E501

        :return: The current_status of this GetCandidatesResponseDataOnDemandInterviewScreening.  # noqa: E501
        :rtype: str
        """
        return self._current_status

    @current_status.setter
    def current_status(self, current_status):
        """Sets the current_status of this GetCandidatesResponseDataOnDemandInterviewScreening.

        Current status of the candidate with respect to this job and this evaluation.  # noqa: E501

        :param current_status: The current_status of this GetCandidatesResponseDataOnDemandInterviewScreening.  # noqa: E501
        :type: str
        """

        self._current_status = current_status

    @property
    def recruiter_user_id(self):
        """Gets the recruiter_user_id of this GetCandidatesResponseDataOnDemandInterviewScreening.  # noqa: E501

        User ID of the recruiter associated with the evaluation.  # noqa: E501

        :return: The recruiter_user_id of this GetCandidatesResponseDataOnDemandInterviewScreening.  # noqa: E501
        :rtype: str
        """
        return self._recruiter_user_id

    @recruiter_user_id.setter
    def recruiter_user_id(self, recruiter_user_id):
        """Sets the recruiter_user_id of this GetCandidatesResponseDataOnDemandInterviewScreening.

        User ID of the recruiter associated with the evaluation.  # noqa: E501

        :param recruiter_user_id: The recruiter_user_id of this GetCandidatesResponseDataOnDemandInterviewScreening.  # noqa: E501
        :type: str
        """

        self._recruiter_user_id = recruiter_user_id

    @property
    def questionnaire_id(self):
        """Gets the questionnaire_id of this GetCandidatesResponseDataOnDemandInterviewScreening.  # noqa: E501

        Identifier of the questionnaire used in the evaluation.  # noqa: E501

        :return: The questionnaire_id of this GetCandidatesResponseDataOnDemandInterviewScreening.  # noqa: E501
        :rtype: str
        """
        return self._questionnaire_id

    @questionnaire_id.setter
    def questionnaire_id(self, questionnaire_id):
        """Sets the questionnaire_id of this GetCandidatesResponseDataOnDemandInterviewScreening.

        Identifier of the questionnaire used in the evaluation.  # noqa: E501

        :param questionnaire_id: The questionnaire_id of this GetCandidatesResponseDataOnDemandInterviewScreening.  # noqa: E501
        :type: str
        """

        self._questionnaire_id = questionnaire_id

    @property
    def video_screen_interview_id(self):
        """Gets the video_screen_interview_id of this GetCandidatesResponseDataOnDemandInterviewScreening.  # noqa: E501

        Video screen interview Identifier.  # noqa: E501

        :return: The video_screen_interview_id of this GetCandidatesResponseDataOnDemandInterviewScreening.  # noqa: E501
        :rtype: str
        """
        return self._video_screen_interview_id

    @video_screen_interview_id.setter
    def video_screen_interview_id(self, video_screen_interview_id):
        """Sets the video_screen_interview_id of this GetCandidatesResponseDataOnDemandInterviewScreening.

        Video screen interview Identifier.  # noqa: E501

        :param video_screen_interview_id: The video_screen_interview_id of this GetCandidatesResponseDataOnDemandInterviewScreening.  # noqa: E501
        :type: str
        """

        self._video_screen_interview_id = video_screen_interview_id

    @property
    def video_screen_id(self):
        """Gets the video_screen_id of this GetCandidatesResponseDataOnDemandInterviewScreening.  # noqa: E501

        Video screen identifier  # noqa: E501

        :return: The video_screen_id of this GetCandidatesResponseDataOnDemandInterviewScreening.  # noqa: E501
        :rtype: str
        """
        return self._video_screen_id

    @video_screen_id.setter
    def video_screen_id(self, video_screen_id):
        """Sets the video_screen_id of this GetCandidatesResponseDataOnDemandInterviewScreening.

        Video screen identifier  # noqa: E501

        :param video_screen_id: The video_screen_id of this GetCandidatesResponseDataOnDemandInterviewScreening.  # noqa: E501
        :type: str
        """

        self._video_screen_id = video_screen_id

    @property
    def interview_title(self):
        """Gets the interview_title of this GetCandidatesResponseDataOnDemandInterviewScreening.  # noqa: E501

        Title of the interview.  # noqa: E501

        :return: The interview_title of this GetCandidatesResponseDataOnDemandInterviewScreening.  # noqa: E501
        :rtype: str
        """
        return self._interview_title

    @interview_title.setter
    def interview_title(self, interview_title):
        """Sets the interview_title of this GetCandidatesResponseDataOnDemandInterviewScreening.

        Title of the interview.  # noqa: E501

        :param interview_title: The interview_title of this GetCandidatesResponseDataOnDemandInterviewScreening.  # noqa: E501
        :type: str
        """

        self._interview_title = interview_title

    @property
    def thumbnail_url(self):
        """Gets the thumbnail_url of this GetCandidatesResponseDataOnDemandInterviewScreening.  # noqa: E501

        Thumbnail URL associated with the evaluation.  # noqa: E501

        :return: The thumbnail_url of this GetCandidatesResponseDataOnDemandInterviewScreening.  # noqa: E501
        :rtype: str
        """
        return self._thumbnail_url

    @thumbnail_url.setter
    def thumbnail_url(self, thumbnail_url):
        """Sets the thumbnail_url of this GetCandidatesResponseDataOnDemandInterviewScreening.

        Thumbnail URL associated with the evaluation.  # noqa: E501

        :param thumbnail_url: The thumbnail_url of this GetCandidatesResponseDataOnDemandInterviewScreening.  # noqa: E501
        :type: str
        """

        self._thumbnail_url = thumbnail_url

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GetCandidatesResponseDataOnDemandInterviewScreening, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetCandidatesResponseDataOnDemandInterviewScreening):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
